<?php


// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Wcap_Add_Settings' ) ) {
	
	class Wcap_Add_Settings {

		
		public static function wcap_update_cron_interval( $old_value, $new_value ) {
			
			// Now if there's an action scheduled, it needs to be updated with the new frequency
			if ( false !== as_next_scheduled_action( 'woocommerce_ac_send_email_action' ) ) {
				as_unschedule_action( 'woocommerce_ac_send_email_action' );
				
				$new_value = $new_value > 0 ? intval( $new_value ) : 0;
				if ( is_integer( $new_value ) && 0 < $new_value ) {
					$new_interval = $new_value * 60;
					as_schedule_recurring_action( time(), $new_interval, 'woocommerce_ac_send_email_action' );
				}
			}
		}

		
		public static function wcap_use_auto_cron( $old_value, $new_value ) {
		
			// Now if there's an action scheduled, it needs to be updated with the new frequency
			if ( false !== as_next_scheduled_action( 'woocommerce_ac_send_email_action' ) && '' == $new_value ) {
				as_unschedule_action( 'woocommerce_ac_send_email_action' );
			} else if ( false === as_next_scheduled_action('woocommerce_ac_send_email_action') && 'on' == $new_value ) {
				$cron_interval = intval( get_option( 'wcap_cron_time_duration', 15 ) ) * 60;
				as_schedule_recurring_action( time(), $cron_interval, 'woocommerce_ac_send_email_action' );
			}
		}

		
		public static function wcap_initialize_plugin_options() {
			// First, we register a section.
			add_settings_section(
				'ac_general_settings_section',         // ID used to identify this section and with which to register options.
				__( 'تنظیمات', 'xcart-tr' ),                  // Title to be displayed on the administration page.
				array( 'Wcap_Add_Settings', 'wcap_general_options_callback' ), // Callback used to render the description of the section.
				'xcart'     // Page on which to add this section of options.
			);

			add_settings_field(
				'ac_enable_cart_emails',
				__( 'فعال سازی پلاگین', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_enable_cart_emails_callback' ),
				'xcart',
				'ac_general_settings_section',
				array( __( 'در صورت خاموش بودن، پلاگین اجرا نمی‌شود.', 'xcart-tr' ) )
			);
			add_settings_field(
				'ac_cart_abandoned_time',
				__( 'زمان دریافت اطلاعات کاربران لاگین شده	', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_cart_abandoned_time_callback' ),
				'xcart',
				'ac_general_settings_section',
				array( __( 'مشخص کنید پس از چند دقیقه، سیستم اطلاعات کاربران لاگین را در صورت رها کردن سبد خرید خود، ثبت کند.', 'xcart-tr' ) )
			);

			add_settings_field(
				'ac_cart_abandoned_time_guest',
				__( 'زمان دریافت اطلاعات کاربران ثبت نام نکرده', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_cart_abandoned_time_guest_callback' ),
				'xcart',
				'ac_general_settings_section',
				array( __( 'مشخص کنید پس از چند دقیقه، سیستم اطلاعات کاربران مهمان را در صورت رها کردن سبد خرید، ثبت کند', 'xcart-tr' ) )
			);

			add_settings_field(
				'ac_delete_abandoned_order_days',
				__( 'حذف سبد خرید رها شده', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_delete_abandoned_orders_days_callback' ),
				'xcart',
				'ac_general_settings_section',
				array( __( 'مشخص کنید سبد‌های خرید رها شده پس از چند روز حذف شوند. نکته: در صورت خالی گذاشتن فیلد، اطلاعات همیشه ذخیره می‌ماند.', 'xcart-tr' ) )
			);


			add_settings_field(
				'ac_disable_guest_cart_email',
				__( 'ردیابی نکردن سبد خرید کاربران لاگین شده.', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_disable_guest_cart_email_callback' ),
				'xcart',
				'ac_general_settings_section',
				array( __( 'سبد خرید کاربرانی که وارد سایت شده‌اند دیگر ردیابی نمی‌شود.', 'xcart-tr' ) )
			);

			add_settings_field(
				'ac_disable_logged_in_cart_email',
				__( 'ردیابی نکردن سبد خرید کاربران لاگین', 'xcart-tr'),
				array( 'Wcap_Add_Settings', 'wcap_disable_logged_in_cart_email_callback' ),
				'xcart',
				'ac_general_settings_section',
				array( __( 'سبد خرید کاربرانی که وارد سایت شده‌اند دیگر ردیابی نمی‌شود.', 'xcart-tr' ) )
			);
			add_settings_field(
				'ac_track_guest_cart_from_cart_page',
				__( 'شروع ردیابی از صفحه Cart', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_track_guest_cart_from_cart_page_callback' ),
				'xcart',
				'ac_general_settings_section',
				array( __( 'در حالت غیر فعال اطلاعات سفارش کاربر فقط در صفحه checkout ذخیره می‌شود', 'xcart-tr' ) )
			);
			add_settings_section(
				'ac_coupon_settings_section',           // ID used to identify this section and with which to register options.
				__( 'تنظیمات کد تخفیف', 'xcart-tr' ),      // Title to be displayed on the administration page.
				array( 'Wcap_Add_Settings', 'wcap_coupon_callback' ), // Callback used to render the description of the section.
				'xcart'     // Page on which to add this section of options.
			);

			add_settings_field(
				'wcap_delete_coupon_data',
				__( 'پاک کردن اتوماتیک کد‌های تخفیف	', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_deleting_coupon_data' ),
				'xcart',
				'ac_coupon_settings_section',
				array( __( 'با فعال کردن این گزینه پس از ۱۵ روز کد‌های تخفیف ایجاد شده، غیر فعال و حذف می‌گردند.', 'xcart-tr' ) )
			);

			add_settings_field(
				'wcap_delete_coupon_data_manually',
				__( 'پاک کردن دستی کد‌های تخفیف	', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_deleting_coupon_data_manually' ),
				'xcart',
				'ac_coupon_settings_section',
				array( __( 'پاک کردن تمام کد‌های تخفیف منقضی و یا استفاده شده.', 'xcart-tr' ) )
			);

			add_settings_field(
				'wcac_delete_plugin_data',
				__( 'پاک کردن اطلاعات پس از حذف پلاگین	', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_deleting_plugin_data' ),
				'xcart',
				'ac_general_settings_section',
				array( __( 'با فعال کردن این گزینه، در صورت حذف پلاگین، اطلاعات دیتابیس پلاگین هم بصورت کامل پاک می‌شود.', 'xcart-tr' ) )
			);

		

			add_settings_section(
				'ac_cron_job_settings_section',           // ID used to identify this section and with which to register options.
				__( 'تنظیمات ارسال یادآور با پیامک', 'xcart-tr' ),      // Title to be displayed on the administration page.
				array( 'Wcap_Add_Settings', 'wcap_cron_job_callback' ), // Callback used to render the description of the section.
				'xcart'     // Page on which to add this section of options.
			);

			$post_link = '<a href="#">here</a>';
			add_settings_field(
				'wcap_use_auto_cron',
				__( 'فعال سازی سرویس یادآور پیامکی سبد خرید رها شده.', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_use_auto_cron_callback' ),
				'xcart',
				'ac_cron_job_settings_section',
				array( " برای فعال سازی قابلیت ارسال زماندار پیامک جهت بازگشت مشتریان به سبد خرید و تکمیل آن، این گزینه را فعال نمایید. این گزینه نیازمند فعال سازی کرون‌جاب می‌باشد. به فایل راهنمای پلاگین مراجعه شود.", 'xcart-tr' )
			);

			add_settings_field(
				'wcap_cron_time_duration',
				__( 'اجرای خودکار پس از X دقیقه', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_cron_time_duration_callback' ),
				'xcart',
				'ac_cron_job_settings_section',
				array( 'مدت زمانی بر حسب دقیقه که سیستم یادآوری پیامکی یکبار اجرا شود و ارسال‌های تازه را در روز انجام دهد. (** راهنما: این زمان با میزان بازدید شما رابطه عکس دارد. بطور مثال در صورتی که روزانه بالای ۱۰۰۰ بازدید کننده یکتا دارید این عدد را بر روی ۵ دقیقه تنظیم کنید. بطور کلی برای وبسایت‌های زیر ۱۰۰۰ بازدید کننده در روز می‌توانید این عدد را ۲۰ دقیقه بگذارید.', 'xcart-tr' )
			);

			// Setting section and field for license options.
			add_settings_section(
				'ac_general_license_key_section',
				__( 'Plugin License Options', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_general_license_key_section_callback' ),
				'woocommerce_ac_license_page'
			);

			add_settings_field(
				'edd_sample_license_key_ac_woo',
				__( 'License Key', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_edd_sample_license_key_ac_woo_callback' ),
				'woocommerce_ac_license_page',
				'ac_general_license_key_section',
				array( __( 'Enter your license key.', 'xcart-tr' ) )
			);

			add_settings_field(
				'activate_license_key_ac_woo',
				__( 'Activate License', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_activate_license_key_ac_woo_callback' ),
				'woocommerce_ac_license_page',
				__( 'ac_general_license_key_section', 'xcart-tr' )
			);

		
			add_settings_section(
				'wcap_sms_settings_section',        // ID used to identify this section and with which to register options.
				__( 'فعال سازی پیامک', 'xcart-tr' ),     // Title to be displayed on the administration page.
				array( 'Wcap_Add_Settings', 'wcap_sms_settings_section_callback' ),       // Callback used to render the description of the section.
				'woocommerce_ac_sms_page'               // Page on which to add this section of options.
			);

			add_settings_field(
				'wcap_enable_sms_reminders',
				__( 'فعال سازی درگاه پیامک', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_enable_sms_reminders_callback' ),
				'woocommerce_ac_sms_page',
				'wcap_sms_settings_section',
				array( '<i></i>', 'xcart-tr' )
			);

			add_settings_field(
				'wcap_sms_from_phone',
				__( 'شماره ارسال کننده', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_sms_from_phone_callback' ),
				'woocommerce_ac_sms_page',
				'wcap_sms_settings_section',
				array( '', 'xcart-tr' )
			);


			add_settings_field(
				'wcap_sms_auth_token',
				__( 'API Key', 'xcart-tr' ),
				array( 'Wcap_Add_Settings', 'wcap_sms_auth_token_callback' ),
				'woocommerce_ac_sms_page',
				'wcap_sms_settings_section',
				array( '' )
			);

			// Finally, we register the fields with WordPress
			register_setting(
				'woocommerce_ac_settings',
				'ac_enable_cart_emails'
			);
			register_setting(
				'woocommerce_ac_settings',
				'ac_cart_abandoned_time',
				array( 'Wcap_Add_Settings', 'wcap_cart_time_validation' )
			);
			register_setting(
				'woocommerce_ac_settings',
				'ac_cart_abandoned_time_guest',
				array( 'Wcap_Add_Settings', 'wcap_cart_time_guest_validation' )
			);
			register_setting(
				'woocommerce_ac_settings',
				'ac_delete_abandoned_order_days',
				array( 'Wcap_Add_Settings', 'wcap_delete_days_validation' )
			);
			register_setting(
				'woocommerce_ac_settings',
				'ac_email_admin_on_recovery'
			);
			register_setting(
				'woocommerce_ac_settings',
				'ac_email_admin_on_abandoned'
			);

			register_setting(
				'woocommerce_ac_settings',
				'ac_disable_guest_cart_email'
			);
			register_setting(
				'woocommerce_ac_settings',
				'ac_disable_logged_in_cart_email'
			);

			register_setting(
				'woocommerce_ac_settings',
				'ac_cart_abandoned_after_x_days_order_placed'
			);

			register_setting(
				'woocommerce_ac_settings',
				'ac_capture_email_from_forms'
			);
			register_setting(
				'woocommerce_ac_settings',
				'ac_email_forms_classes'
			);

			register_setting(
				'woocommerce_ac_settings',
				'ac_capture_email_address_from_url'
			);

			register_setting(
				'woocommerce_ac_settings',
				'wcap_guest_cart_capture_msg'
			);

			register_setting(
				'woocommerce_ac_settings',
				'wcap_logged_cart_capture_msg'
			);

	      	register_setting(
		        'woocommerce_ac_settings',
		        'wcap_gdpr_allow_opt_out'
	      	);
	            
	      	register_setting(
		        'woocommerce_ac_settings',
		        'wcap_gdpr_opt_out_message'
	      	);
	      	
	      	register_setting(
	        	'woocommerce_ac_settings',
	        	'wcap_delete_coupon_data'
	      	);

	      	register_setting(
	        	'woocommerce_ac_settings',
	        	'wcac_delete_plugin_data'
	      	);
            
			register_setting(
				'woocommerce_ac_settings',
				'ac_track_guest_cart_from_cart_page'
			);
			register_setting(
				'woocommerce_ac_license',
				'edd_sample_license_key_ac_woo'
			);

			register_setting(
				'woocommerce_ac_settings',
				'wcap_cron_time_duration'
			);
			register_setting(
				'woocommerce_ac_settings',
				'wcap_use_auto_cron'
			);

			register_setting(
				'woocommerce_ac_settings',
				'wcap_restrict_ip_address'
			);
			register_setting(
				'woocommerce_ac_settings',
				'wcap_restrict_email_address'
			);
			register_setting(
				'woocommerce_ac_settings',
				'wcap_restrict_domain_address'
			);

			register_setting(
				'woocommerce_ac_settings',
				'wcap_from_name'
			);
			register_setting(
				'woocommerce_ac_settings',
				'wcap_from_email'
			);
			register_setting(
				'woocommerce_ac_settings',
				'wcap_reply_email'
			);
			register_setting(
				'woocommerce_ac_settings',
				'wcap_product_image_height'
			);

			register_setting(
				'woocommerce_ac_settings',
				'wcap_product_image_width'
			);

			register_setting(
				'woocommerce_ac_settings',
				'wcap_product_name_redirect'
			);

			register_setting(
				'woocommerce_ac_settings',
				'wcap_add_utm_to_links'
			);

			register_setting(
				'woocommerce_sms_settings',
				'wcap_enable_sms_reminders'
			);

			register_setting(
				'woocommerce_sms_settings',
				'wcap_sms_from_phone'
			);

			register_setting(
				'woocommerce_sms_settings',
				'wcap_sms_account_sid'
			);

			register_setting(
				'woocommerce_sms_settings',
				'wcap_sms_auth_token'
			);

			do_action( 'wcap_add_new_settings' );
		}

		
		public static function wcap_cart_time_validation( $input ) {
			$output = '';
			if ( $input != '' && ( is_numeric( $input ) && $input > 0 ) ) {
				$output = stripslashes( $input );
			} else {
				add_settings_error( 'ac_cart_abandoned_time', 'error found', __( 'XCart cut off time for logged-in users should be numeric and has to be greater than 0.', 'xcart-tr' ) );
			}

			return $output;
		}

		
		public static function wcap_cart_time_guest_validation( $input ) {
			$output = '';
			if ( $input != '' && ( is_numeric( $input ) && $input > 0 ) ) {
				$output = stripslashes( $input );
			} else {
				add_settings_error( 'ac_cart_abandoned_time_guest', 'error found', __( '', 'xcart-tr' ) );
			}

			return $output;
		}

		
		public static function wcap_delete_days_validation( $input ) {
			$output = '';
			if ( $input == '' || ( is_numeric( $input ) && $input > 0 ) ) {
				$output = stripslashes( $input );
			} else {
				add_settings_error( 'ac_delete_abandoned_order_days', 'error found', __( '', 'xcart-tr' ) );
			}

			return $output;
		}

		
		public static function wcap_general_options_callback() {
		}

		
		public static function wcap_enable_cart_emails_callback( $args ) {
			// First, we read the option.
			$enable_cart_emails = get_option( 'ac_enable_cart_emails' );
			// This condition added to avoid the notice displayed while Check box is unchecked.
			if ( isset( $enable_cart_emails ) && $enable_cart_emails == '' ) {
				$enable_cart_emails = 'off';
			}
			// Next, we update the name attribute to access this element's ID in the context of the display options array.
			// We also access the show_header element of the options collection in the call to the checked() helper function.
			echo '<input type="checkbox" id="ac_enable_cart_emails" name="ac_enable_cart_emails" value="on" ', checked( 'on', $enable_cart_emails, false ), '/>';
			// Here, we'll take the first argument of the array and add it to a label next to the check box.
			echo '<label for="ac_enable_cart_emails"> ', esc_attr( $args[0] ), '</label>';
		}

		
		public static function wcap_cart_abandoned_time_callback( $args ) {
			// First, we read the option.
			$cart_abandoned_time = get_option( 'ac_cart_abandoned_time' );
			// Next, we update the name attribute to access this element's ID in the context of the display options array.
			// We also access the show_header element of the options collection in the call to the checked() helper function.
			printf(
				'<input type="text" id="ac_cart_abandoned_time" name="ac_cart_abandoned_time" value="%s" />',
				isset( $cart_abandoned_time ) ? esc_attr( $cart_abandoned_time ) : ''
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox.
			echo '<label for="ac_cart_abandoned_time"> ', esc_attr( $args[0] ), '</label>';
		}

		
		public static function wcap_cart_abandoned_time_guest_callback( $args ) {
			// First, we read the option
			$cart_abandoned_time_guest = get_option( 'ac_cart_abandoned_time_guest' );
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function
			printf(
				'<input type="text" id="ac_cart_abandoned_time_guest" name="ac_cart_abandoned_time_guest" value="%s" />',
				isset( $cart_abandoned_time_guest ) ? esc_attr( $cart_abandoned_time_guest ) : ''
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html = '<label for="ac_cart_abandoned_time_guest"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_delete_abandoned_orders_days_callback( $args ) {
			// First, we read the option
			$delete_abandoned_order_days = get_option( 'ac_delete_abandoned_order_days' );
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function
			printf(
				'<input type="text" id="ac_delete_abandoned_order_days" name="ac_delete_abandoned_order_days" value="%s" />',
				isset( $delete_abandoned_order_days ) ? esc_attr( $delete_abandoned_order_days ) : ''
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html = '<label for="ac_delete_abandoned_order_days"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_cart_abandoned_after_x_days_order_placed_callback( $args ) {

			$ac_cart_abandoned_after_x_days_order_placed = get_option( 'ac_cart_abandoned_after_x_days_order_placed' );

			if ( '' == $ac_cart_abandoned_after_x_days_order_placed ){
				$ac_cart_abandoned_after_x_days_order_placed = 0;
			}

			printf(
				'<input type="number" id="ac_cart_abandoned_after_x_days_order_placed" name="ac_cart_abandoned_after_x_days_order_placed" value="%s" />',
				isset( $ac_cart_abandoned_after_x_days_order_placed ) ? esc_attr( $ac_cart_abandoned_after_x_days_order_placed ) : ''
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html = '<label for="ac_cart_abandoned_after_x_days_order_placed"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_email_admin_on_recovery_callback( $args ) {
			// First, we read the option
			$email_admin_on_recovery = get_option( 'ac_email_admin_on_recovery' );
			// This condition added to avoid the notie displyed while Check box is unchecked.
			if ( isset( $email_admin_on_recovery ) && $email_admin_on_recovery == '' ) {
				$email_admin_on_recovery = 'off';
			}
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function
			$html = '';
			printf(
				'<input type="checkbox" id="ac_email_admin_on_recovery" name="ac_email_admin_on_recovery" value="on"
                ' . checked( 'on', $email_admin_on_recovery, false ) . ' />'
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html .= '<label for="ac_email_admin_on_recovery"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_disable_guest_cart_email_callback( $args ) {
			// First, we read the option
			$disable_guest_cart_email = get_option( 'ac_disable_guest_cart_email' );
			// This condition added to avoid the notie displyed while Check box is unchecked.
			if ( isset( $disable_guest_cart_email ) && $disable_guest_cart_email == '' ) {
				$disable_guest_cart_email = 'off';
			}
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function.
			printf(
				'<input type="checkbox" id="ac_disable_guest_cart_email" name="ac_disable_guest_cart_email" value="on"
                ' . checked( 'on', $disable_guest_cart_email, false ) . ' />'
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox.
			echo '<label for="ac_disable_guest_cart_email"> ', esc_attr( $args[0] ), '</label> <br> <div id ="wcap_atc_disable_msg" class="wcap_atc_disable_msg"></div>';
		}

		
		public static function wcap_disable_logged_in_cart_email_callback( $args ) {
			// First, we read the option.
			$disable_logged_in_cart_email = get_option( 'ac_disable_logged_in_cart_email' );
			// This condition added to avoid the notice displyed while Check box is unchecked.
			if ( isset( $disable_logged_in_cart_email ) && $disable_logged_in_cart_email == '' ) {
				$disable_logged_in_cart_email = 'off';
			}
			// Next, we update the name attribute to access this element's ID in the context of the display options array.
			// We also access the show_header element of the options collection in the call to the checked() helper function.
			printf(
				'<input type="checkbox" id="ac_disable_logged_in_cart_email" name="ac_disable_logged_in_cart_email" value="on"
                ' . checked( 'on', $disable_logged_in_cart_email, false ) . ' />'
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox.
			echo '<label for="ac_disable_logged_in_cart_email"> ', esc_attr( $args[0] ), '</label>';
		}

		
		public static function wcap_capture_email_from_forms( $args ) {
			// First, we read the option.
			$capture_email_forms = get_option( 'ac_capture_email_from_forms' );
			// This condition added to avoid the notice displyed while Check box is unchecked.
			if ( isset( $capture_email_forms ) && '' === $capture_email_forms ) {
				$capture_email_forms = 'off';
			}
			// Next, we update the name attribute to access this element's ID in the context of the display options array.
			// We also access the show_header element of the options collection in the call to the checked() helper function.
			printf(
				'<input type="checkbox" id="ac_capture_email_from_forms" name="ac_capture_email_from_forms" value="on"
                ' . checked( 'on', $capture_email_forms, false ) . ' />'
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox.
			echo '<label for="ac_capture_email_from_forms"> ', esc_attr( $args[0] ), '</label>';
		}

		
		public static function wcap_email_forms_classes( $args ) {
			// First, we read the option.
			$email_forms_classes = get_option( 'ac_email_forms_classes' );

			$readonly_param = ( get_option( 'ac_capture_email_from_forms' ) === '' ) ? 'readonly="readonly"' : '';
			// Next, we update the name attribute to access this element's ID in the context of the display options array.
			// We also access the show_header element of the options collection in the call to the checked() helper function.
			printf(
				'<textarea rows="4" cols="80" id="ac_email_forms_classes" name="ac_email_forms_classes" %s>%s</textarea>',
				esc_attr( $readonly_param ),
				isset( $email_forms_classes ) ? esc_attr( $email_forms_classes ) : ''
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox.
			echo '<br><label for="ac_email_forms_classes"> ', esc_attr( $args[0] ), '</label>';
		}

		
		public static function wcap_capture_email_address_from_url( $args ) {
			// First, we read the option
			$ac_capture_email_address_from_url = get_option( 'ac_capture_email_address_from_url' );
			// Next, we update the name attribute to access this element's ID in the context of the display options array.
			// We also access the show_header element of the options collection in the call to the checked() helper function.
			printf(
				'<input type="text" id="ac_capture_email_address_from_url" name="ac_capture_email_address_from_url" value="%s" />',
				isset( $ac_capture_email_address_from_url ) ? esc_attr( $ac_capture_email_address_from_url ) : ''
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox.
			$html = '<label for="ac_capture_email_address_from_url_label"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_guest_cart_capture_msg_callback( $args ) {
			$guest_msg = get_option( 'wcap_guest_cart_capture_msg' );

			$html = "<textarea rows='4' cols='80' id='wcap_guest_cart_capture_msg' name='wcap_guest_cart_capture_msg'>$guest_msg</textarea>";

			$html .= '<label for="wcap_guest_cart_capture_msg"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_logged_cart_capture_msg_callback( $args ) {
			$logged_msg = get_option( 'wcap_logged_cart_capture_msg' );

			$html = "<input type='text' class='regular-text' id='wcap_logged_cart_capture_msg' name='wcap_logged_cart_capture_msg' value='$logged_msg' />";

			$html .= '<label for="wcap_logged_cart_capture_msg"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_gdpr_allow_opt_out_callback( $args ) {

			$wcap_gdpr_allow_opt_out = get_option( 'wcap_gdpr_allow_opt_out' );

			$html = "<input type='text' class='regular-text' id='wcap_gdpr_allow_opt_out' name='wcap_gdpr_allow_opt_out' value='" . htmlspecialchars( $wcap_gdpr_allow_opt_out, ENT_QUOTES ) . "' />";

			$html .= '<label for="wcap_gdpr_allow_opt_out"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_gdpr_opt_out_msg_callback( $args ) {

			$wcap_gdpr_opt_out_message = get_option( 'wcap_gdpr_opt_out_message' );

			$html = "<input type='text' id='wcap_gdpr_opt_out_message' name='wcap_gdpr_opt_out_message' value='" . htmlspecialchars( $wcap_gdpr_opt_out_message, ENT_QUOTES ) . "' style='width:60%;'/>";

			$html .= '<label for="wcap_gdpr_opt_out_message"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_deleting_coupon_data( $args ) {
			$wcap_delete_coupon_data = get_option( 'wcap_delete_coupon_data', '' );
			if ( isset( $wcap_delete_coupon_data ) && '' === $wcap_delete_coupon_data ) {
				$wcap_delete_coupon_data = 'off';
				wp_clear_scheduled_hook( 'woocommerce_ac_delete_coupon_action' );
			} else {
				if ( ! wp_next_scheduled( 'woocommerce_ac_delete_coupon_action' ) ) {
				    wp_schedule_event( time(), 'wcap_15_days', 'woocommerce_ac_delete_coupon_action' );
				}
			}

			?>
			<input type="checkbox" id="wcap_delete_coupon_data" name="wcap_delete_coupon_data" value="on" <?php echo checked( 'on', $wcap_delete_coupon_data, false ); ?> />
			<label for="wcap_delete_coupon_data"> <?php echo esc_attr( $args[0] ); ?></label>
			<a >
			<?php
		}

		public static function wcap_deleting_coupon_data_manually( $args ) {
			?>
			<!-- <a href="#" class="button button-large wcap_delete_coupon"><?php //echo __( "Delete", "xcart-tr" ); ?></a> -->
			<input type="button" class="button-secondary" id="wcap_delete_coupons" value="<?php esc_html_e( 'حذف', 'xcart-tr' ); ?>" >
			<label> <?php echo esc_attr( $args[0] ); ?></label>
			<br>
			<span class="wcap-spinner" style="display:none;">
				<img class="ajax_img" src="<?php echo WCAP_PLUGIN_URL . '/assets/images/ajax-loader.gif';?>" />
			</span>
			<span class="wcap-coupon-response-msg"></span>
			<?php
		}

		
		public static function wcap_deleting_plugin_data( $args ) {
			$wcac_delete_plugin_data = get_option( 'wcac_delete_plugin_data' );
			if ( isset( $wcac_delete_plugin_data ) && '' === $wcac_delete_plugin_data ) {
				$wcac_delete_plugin_data = 'off';
			}
			?>
			<input type="checkbox" id="wcac_delete_plugin_data" name="wcac_delete_plugin_data" value="on" <?php echo checked( 'on', $wcac_delete_plugin_data, false ); ?> />
			<label for="wcac_delete_plugin_data"> <?php echo esc_attr( $args[0] ); ?></label>
			<?php
		}

		
		public static function wcap_track_guest_cart_from_cart_page_callback( $args ) {
			// First, we read the option
			$disable_guest_cart_from_cart_page = get_option( 'ac_track_guest_cart_from_cart_page' );
			$disable_guest_cart_email          = get_option( 'ac_disable_guest_cart_email' );
			// This condition added to avoid the notice displyed while Check box is unchecked.
			if ( isset( $disable_guest_cart_from_cart_page ) && $disable_guest_cart_from_cart_page == '' ) {
				$disable_guest_cart_from_cart_page = 'off';
			}
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function
			$html     = '';
			$disabled = '';
			if ( isset( $disable_guest_cart_email ) && $disable_guest_cart_email == 'on' ) {
				$disabled                          = 'disabled';
				$disable_guest_cart_from_cart_page = 'off';
			}
			printf(
				'<input type="checkbox" id="ac_track_guest_cart_from_cart_page" name="ac_track_guest_cart_from_cart_page" value="on"
                ' . checked( 'on', $disable_guest_cart_from_cart_page, false ) . '
                ' . $disabled . ' />'
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html .= '<label for="ac_track_guest_cart_from_cart_page"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_email_callback() {
		}

		
		public static function wcap_coupon_callback() {
		}

		
		public static function wcap_from_name_callback( $args ) {
			// First, we read the option
			$wcap_from_name = get_option( 'wcap_from_name' );
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function
			printf(
				'<input type="text" id="wcap_from_name" name="wcap_from_name" value="%s" />',
				isset( $wcap_from_name ) ? esc_attr( $wcap_from_name ) : ''
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html = '<label for="wcap_from_name_label"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_from_email_callback( $args ) {
			// First, we read the option
			$wcap_from_email = get_option( 'wcap_from_email' );
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function
			printf(
				'<input type="text" id="wcap_from_email" name="wcap_from_email" value="%s" />',
				isset( $wcap_from_email ) ? esc_attr( $wcap_from_email ) : ''
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html = '<label for="wcap_from_email_label"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_reply_email_callback( $args ) {
			// First, we read the option
			$wcap_reply_email = get_option( 'wcap_reply_email' );
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function
			printf(
				'<input type="text" id="wcap_reply_email" name="wcap_reply_email" value="%s" />',
				isset( $wcap_reply_email ) ? esc_attr( $wcap_reply_email ) : ''
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html = '<label for="wcap_reply_email_label"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_product_image_size_callback( $args ) {
			// First, we read the option
			$wcap_product_image_height = get_option( 'wcap_product_image_height' );
			$wcap_product_image_width  = get_option( 'wcap_product_image_width' );
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function
			?> <input type="text" id = "wcap_product_image_height" style= "width:50px" name="wcap_product_image_height" value="<?php echo $wcap_product_image_height; ?>" />
			 <?php echo 'x'; ?>
			 <input type="text" id = "wcap_product_image_width" style = "width:50px" name="wcap_product_image_width" value="<?php echo $wcap_product_image_width; ?>" />
			 px
			<?php
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html = '<label for="wcap_product_image_size"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_product_name_redirect_callback( $args ) {

			$wcap_product_name_redirect = get_option( 'wcap_product_name_redirect', 'checkout' );

			$pages = array(
				'product'  => __( 'Product Page', 'xcart-tr'),
				'checkout' => __( 'Checkout Page', 'xcart-tr' ),
			);
			?>
			<select id='wcap_product_name_redirect' name='wcap_product_name_redirect'>
			<?php
			foreach ( $pages as $slug => $display ) {
				$selected = $slug === $wcap_product_name_redirect ? 'selected' : '';
				echo sprintf(
					'<option value="%s" %s>%s</option>',
					esc_attr( $slug ),
					esc_attr( $selected ),
					esc_attr( $display )
				);
			}
			?>
			</select>
			<?php
			$html = '<label for="wcap_product_name_redirect">' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_add_utm_to_links_callback( $args ) {

			$wcap_add_utm_to_links = get_option( 'wcap_add_utm_to_links', '' );

			?>
			<textarea id='wcap_add_utm_to_links' rows='4' cols='50' name='wcap_add_utm_to_links'><?php echo esc_html( $wcap_add_utm_to_links ); ?></textarea>
			<?php
			$html = '<label for="wcap_add_utm_to_links">' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_cron_job_callback() {
		}

		
		public static function wcap_use_auto_cron_callback( $args ) {
			// First, we read the option
			$enable_auto_cron = get_option( 'wcap_use_auto_cron' );

			// This condition added to avoid the notie displyed while Check box is unchecked.
			if ( isset( $enable_auto_cron ) && '' == $enable_auto_cron ) {
				$enable_auto_cron = 'off';
			}
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function
			$html = '';
			printf(
				'<input type="checkbox" id="wcap_use_auto_cron" name="wcap_use_auto_cron" value="on"
                ' . checked( 'on', $enable_auto_cron, false ) . ' />'
			);
			// $html = '<input type="checkbox" id="wcap_use_auto_cron" name="wcap_use_auto_cron" value="on" ' . checked( 'on', $enable_auto_cron, false ) . '/>';
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html .= '<label for="wcap_use_auto_cron_label"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_cron_time_duration_callback( $args ) {
			// First, we read the option
			$wcap_cron_time_duration = get_option( 'wcap_cron_time_duration' );
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function
			printf(
				'<input type="text" id="wcap_cron_time_duration" name="wcap_cron_time_duration" value="%s" />',
				isset( $wcap_cron_time_duration ) ? esc_attr( $wcap_cron_time_duration ) : ''
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html = '<label for="wcap_cron_time_duration"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_general_license_key_section_callback() {
		}

		
		public static function wcap_edd_sample_license_key_ac_woo_callback( $args ) {
			$edd_sample_license_key_ac_woo_field = get_option( 'edd_sample_license_key_ac_woo' );
			printf(
				'<input type="text" id="edd_sample_license_key_ac_woo" name="edd_sample_license_key_ac_woo" class="regular-text" value="%s" />',
				isset( $edd_sample_license_key_ac_woo_field ) ? esc_attr( $edd_sample_license_key_ac_woo_field ) : ''
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html = '<label for="edd_sample_license_key_ac_woo"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_activate_license_key_ac_woo_callback() {
			$license = get_option( 'edd_sample_license_key_ac_woo' );
			$status  = get_option( 'edd_sample_license_status_ac_woo' );
			?>
				<form method="post" action="options.php">
				<?php
				if ( false !== $license ) {
					?>
					<?php
					if ( $status !== false && $status == 'valid' ) {
						?>
						<span style="color:green;"><?php _e( 'active' ); ?></span>
						<?php wp_nonce_field( 'edd_sample_nonce', 'edd_sample_nonce' ); ?>
						<input type="submit" class="button-secondary" name="edd_ac_license_deactivate" value="<?php _e( 'Deactivate License' ); ?>"/>
						<?php
					} else {
						?>

								<?php
								wp_nonce_field( 'edd_sample_nonce', 'edd_sample_nonce' );
								?>

								<input type="submit" class="button-secondary" name="edd_ac_license_activate" value="<?php _e( 'Activate License' ); ?>"/>
								<?php
					}
					?>
					<?php
				}
				?>
				</form>
			<?php
		}

		
		public static function wcap_custom_restrict_callback() {
		}

		
		public static function wcap_restrict_ip_address_callback( $args ) {
			// First, we read the option
			$wcap_restrict_ip_address = get_option( 'wcap_restrict_ip_address' );
			$value                    = isset( $wcap_restrict_ip_address ) ? esc_attr( $wcap_restrict_ip_address ) : '';
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function
			printf(
				'<textarea rows="4" cols="50" id="wcap_restrict_ip_address" name="wcap_restrict_ip_address" placeholder="یک IP وارد کنید." />' . $value . '</textarea>'
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html = '<label for="wcap_restrict_ip_address_label"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_restrict_email_address_callback( $args ) {
			// First, we read the option
			$wcap_restrict_email_address = get_option( 'wcap_restrict_email_address' );
			$email_value                 = isset( $wcap_restrict_email_address ) ? esc_attr( $wcap_restrict_email_address ) : '';
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function
			printf(
				'<textarea rows="4" cols="50" id="wcap_restrict_email_address" name="wcap_restrict_email_address" placeholder="در هر خط یک ایمیل" />' . $email_value . '</textarea>'
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html = '<label for="wcap_restrict_email_address_label"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_restrict_domain_address_callback( $args ) {
			// First, we read the option
			$wcap_restrict_domain_address = get_option( 'wcap_restrict_domain_address' );
			$domain_value                 = isset( $wcap_restrict_domain_address ) ? esc_attr( $wcap_restrict_domain_address ) : '';
			// Next, we update the name attribute to access this element's ID in the context of the display options array
			// We also access the show_header element of the options collection in the call to the checked() helper function
			printf(
				'<textarea rows="4" cols="50" id="wcap_restrict_domain_address" name="wcap_restrict_domain_address" placeholder="Add an email domain name (Ex. hotmail.com)" />' . $domain_value . '</textarea>'
			);
			// Here, we'll take the first argument of the array and add it to a label next to the checkbox
			$html = '<label for="wcap_restrict_domain_address_label"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		 
		public static function wcap_sms_settings_section_callback() {
			_e( 'پیشنهاد ما استفاده از سرویس پیامکی کاوه نگار است.', 'xcart-tr' );
		}
		

		
		public static function wcap_enable_sms_reminders_callback( $args ) {
			$wcap_enable_sms = get_option( 'wcap_enable_sms_reminders' );

			if ( isset( $wcap_enable_sms ) && $wcap_enable_sms == '' ) {
				$wcap_enable_sms = 'off';
			}

			$html = '<input type="checkbox" class="chechkbox-xcart" id="wcap_enable_sms_reminders" name="wcap_enable_sms_reminders" value="on" ' . checked( 'on', $wcap_enable_sms, false ) . '/>';

			$html .= '<label for="wcap_enable_sms_reminders"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_sms_from_phone_callback( $args ) {
			$wcap_from_phone = get_option( 'wcap_sms_from_phone' );

			$html = "<input type='text' id='wcap_sms_from_phone' name='wcap_sms_from_phone' value='$wcap_from_phone'  />";

			$html .= '<label for="wcap_from_phone"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_sms_account_sid_callback( $args ) {
			$wcap_sms_account_sid = get_option( 'wcap_sms_account_sid' );

			$html = "<input type='text' style='width:60%;' id='wcap_sms_account_sid' name='wcap_sms_account_sid' value='$wcap_sms_account_sid'  />";

			$html .= '<label for="wcap_sms_account_sid"> ' . $args[0] . '</label>';
			echo $html;
		}

		
		public static function wcap_sms_auth_token_callback( $args ) {
			$wcap_sms_auth_token = get_option( 'wcap_sms_auth_token' );

			$html = "<input type='text' style='width:60%;' id='wcap_sms_auth_token' name='wcap_sms_auth_token' value='$wcap_sms_auth_token'  />";

			$html .= '<label for="wcap_sms_auth_token"> ' . $args[0] . '</label>';
			echo $html;
		}
	}
}
?>
