<?php


if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

class Wcap_Sent_SMS_Table extends WP_List_Table {

	
	public $per_page = 30;

	
	public $base_url;

	
	public $total_count;

	
	public $link_click_count;

	
	public $start_date_db;

	
	public $end_date_db;

	
	public $duration;

   	
	public function __construct() {
		global $status, $page;
		
		parent::__construct( array(
	        'singular' => __( 'sent_sms_id', 'xcart-tr' ), //singular name of the listed records
	        'plural'   => __( 'sent_sms_ids', 'xcart-tr' ), //plural name of the listed records
			'ajax'      => true             			
		) );

		$this->base_url = admin_url( 'admin.php?page=xcart&action=stats&section=sms' );
	}
	
	
	public function wcap_sent_sms_prepare_items() {

		$columns               = $this->get_columns();
		$hidden                = array(); 
		$data                  = $this->wcap_sent_sms_data();
		$total_items           = $this->total_count;
 		$link_click_count      = $this->link_click_count;
		$this->items           = $data;
		$this->_column_headers = array( $columns, $hidden);
		$this->set_pagination_args( array(
                'total_items' => $total_items,                  	
                'per_page'    => $this->per_page,                     	
                'total_pages' => ceil( $total_items / $this->per_page )   
            )
		); 
	}

	
	public function get_columns() {

	    $columns = array(
	    	'cb'                => '<input type="checkbox" />',
	        'user_phone_number' => __( 'شماره تماس کاربر'       , 'xcart-tr' ),
            'sent_time'         => __( 'تاریخ ارسال پیام'          , 'xcart-tr' ),
	        'date_time_opened'  => __( 'تاریخ باز شدن لینک', 'xcart-tr' ),
			'link_clicked'  	=> __( 'آخرین مکان کاربر'             , 'xcart-tr' ),
            'template_name'     => __( 'قالب پیام ارسال شده'      , 'xcart-tr'),
	    );
		return apply_filters( 'wcap_sent_sms_columns', $columns );
	}

	
	function column_cb( $item ) {
	    $wcap_email_sent_id = '';
	    if( isset( $item->sms_sent_id ) && "" != $item->sms_sent_id ) {
	       $wcap_sms_sent_id = $item->sms_sent_id;
 	       return sprintf(
	           '<input type="checkbox" name="%1$s[]" value="%2$s" />',
	           'wcap_email_sent_id',
	           $wcap_sms_sent_id
	       );
	    }
	}
	
    
    function column_user_phone_number( $sent_sms_row_info ) {

	    $row_actions = array();
	    $value = '';
	    $sent_id = 0;

	    if( isset( $sent_sms_row_info->user_phone_number ) ){
	        $display_link = $sent_sms_row_info->display_link ;
    	    if ( "Abandoned" == $display_link ){

    	    	$wcap_array = array(
								'action' => 'wcap_abandoned_cart_info',
								'cart_id' => $sent_sms_row_info->abandoned_order_id
					    	);
            	$wcap_url = add_query_arg(
            					$wcap_array , admin_url( 'admin-ajax.php' )
        					);

				$view_name = __( "Abandoned Order", "xcart-tr" );
    	        $row_actions['view_details']   = "<a class=wcap-js-open-modal data-wcap-cart-id=".$sent_sms_row_info->abandoned_order_id." data-wcap-cart-id=".$sent_sms_row_info->abandoned_order_id." data-modal-type=ajax href = $wcap_url>". $view_name ."</a>";
    	    }else{
    	        $view_link = "post.php?post=" . $sent_sms_row_info->recovered_order_id . "&action=edit";
    	        $view_name = __( " Recovered Order", "xcart-tr" );
    	        $row_actions['view_details']   = "<a target=_blank href = $view_link>". $view_name ."</a>";
    	    }
			$user_name = $sent_sms_row_info->user_phone_number; 
            $value     = $user_name . $this->row_actions( $row_actions ); 
	    }
        return apply_filters( 'wcap_sent_sms_single_column', $value, $sent_id, 'sms' );
	}
	
    
	static function get_sms_template_ids() {
	    global $wpdb;
	    
	    $sms_query = "SELECT id FROM " . WCAP_NOTIFICATIONS . "
	                   WHERE type = 'sms'";
	    
	    $get_sms = $wpdb->get_col( $sms_query );
	    
	    if( is_array( $get_sms ) && count( $get_sms ) > 0 ) {
	        return $get_sms;
	    } else {
	        return false;
	    }
	}
	
	
	public function wcap_sent_sms_data() {

	    global $wpdb;
	    $wcap_class 	  = new xcart_ap ();
	    
	    
	    if ( isset( $_POST['duration_select_sms'] ) && '' != $_POST['duration_select_sms'] ){
	        $duration_range         = $_POST['duration_select_sms'];
	        $_SESSION['duration']   = $duration_range;
	    } else if ( isset( $_SESSION ['duration'] ) && '' != $_SESSION ['duration'] ){
	        $duration_range         = $_SESSION ['duration'];
	    }
	    
	    if ( ! isset( $duration_range ) || ( isset( $duration_range ) && '' == $duration_range ) ) {
	        $duration_range         = "last_seven";
	        $_SESSION['duration']   = $duration_range;
	    }
	     
	    
	    $start_date_range = '';
	    if ( isset( $_POST['start_date_sms'] ) && '' != $_POST['start_date_sms'] ) {
	        $start_date_range        = $_POST['start_date_sms'];
	        $_SESSION ['start_date'] = $start_date_range;
	    } else if ( isset( $_SESSION ['start_date'] ) &&  '' != $_SESSION ['start_date'] ) {
	        $start_date_range = $_SESSION ['start_date'];
	    }
	    
	    if ( '' == $start_date_range ) {
	        $start_date_range = $wcap_class->start_end_dates[$duration_range]['start_date'];
	        $_SESSION ['start_date'] = $start_date_range;
	    }
	    
	    
	    $end_date_range = '';
	    if ( isset( $_POST['end_date_sms'] ) && '' != $_POST['end_date_sms'] ){
	        $end_date_range = $_POST['end_date_sms'];
	        $_SESSION ['end_date'] = $end_date_range;
	    } else if ( isset($_SESSION ['end_date'] ) && '' != $_SESSION ['end_date'] ){
	        $end_date_range = $_SESSION ['end_date'];
	    }
	    
	    if ( '' == $end_date_range ) {
	        $end_date_range = $wcap_class->start_end_dates[$duration_range]['end_date'];
	        $_SESSION ['end_date'] = $end_date_range;
	    }
	     
	    $start_date    		= strtotime( $start_date_range." 00:00:00" );
	    $end_date      		= strtotime( $end_date_range." 23:59:59" );
	    
	    $results_sms_sent = array();
	    
	    $total_sms_sent = 0;
	    $total_links_clicked = 0;
	    
	    $msg_ids = array();
	    
	    $sms_templates = self::get_sms_template_ids();
	    
	    
	    if( $sms_templates ) {
	        $i = 0;
	             
	        $template_ids_str = implode( ',', $sms_templates );
	        
            
            $get_data = "SELECT id, template_id, cart_id, notification_data FROM " . WCAP_TINY_URLS . "
                           WHERE date_created >= %s
                           AND date_created <= %s
                           AND template_id IN ($template_ids_str)
                           ORDER BY date_created DESC";
            
            $sms_data = $wpdb->get_results( $wpdb->prepare( $get_data, $start_date, $end_date ) );
    
            if( is_array( $sms_data ) && count( $sms_data ) > 0 ) {

                foreach( $sms_data as $display_data ) {
                    
                    if( $display_data->notification_data != '' ) {
	                    
	                    $display_data_decoded = json_decode( $display_data->notification_data );

	                    if( isset( $display_data_decoded->msg_id ) && isset( $display_data_decoded->phone_number ) && '' != $display_data_decoded->phone_number ) {
	                        
	                        
	                        if( ! in_array( $display_data_decoded->msg_id, $msg_ids ) ) {
	                           $msg_ids[ $i ] = $display_data_decoded->msg_id;
	                        } else {
	                            
	                            $key = array_search( $display_data_decoded->msg_id, $msg_ids );
	                            
	                            
	                            if( is_int( $key ) ) {
	                                
	                                if( $results_sms_sent[ $key ]->sent_time == '' ) {
	                                   $results_sms_sent[ $key ]->date_time_opened = isset( $display_data_decoded->link_opened_time ) ? $display_data_decoded->link_opened_time : '';
	                                   $results_sms_sent[ $key ]->link_clicked = isset( $display_data_decoded->link_clicked ) && '' != $display_data_decoded->link_opened_time ? $display_data_decoded->link_clicked : '';
	                                } else if( isset( $display_data_decoded->link_opened_time ) ) {
	                                    $results_sms_sent[ $key ]->date_time_opened .= ',' . $display_data_decoded->link_opened_time;
	                                    if( isset( $display_data_decoded->link_clicked ) ) {
	                                       $results_sms_sent[ $key ]->link_clicked .= ',' . $display_data_decoded->link_clicked;
	                                    }
	                                }
            	                    
	                            }
	                            continue;
	                        }
	                        $template_id = $display_data->template_id;
	                        
    	                    $results_sms_sent[$i] = new stdClass();
    	                    
    	                    $results_sms_sent[$i]->sms_sent_id = $display_data->id;
    	                    
    	                    $results_sms_sent[$i]->user_phone_number = $display_data_decoded->phone_number;
    	                    
    	                    
    	                    $results_sms_sent[$i]->sent_time = $display_data_decoded->sent_time;
    	                    
    	                    
    	                    $results_sms_sent[$i]->date_time_opened = isset( $display_data_decoded->link_opened_time ) ? $display_data_decoded->link_opened_time : '';
    	                    
    	                    
                            $results_sms_sent[$i]->link_clicked = isset( $display_data_decoded->link_clicked ) && '' != $results_sms_sent[$i]->date_time_opened ? $display_data_decoded->link_clicked : '';  	                    

	                        
    	                    $results_sms_sent[$i]->template_name = $template_id;
    	                    
    	                    
    	                    $abandoned_order_id = $display_data->cart_id;
    	                    $results_sms_sent[$i]->abandoned_order_id = $abandoned_order_id;
    	                    
    	                    
    	                    $recovered_query = "SELECT recovered_cart FROM `" . WCAP_ABANDONED_CART_HISTORY_TABLE . "`
    	                                           WHERE id = %d";
    	                    $recovered_result = $wpdb->get_col( $wpdb->prepare( $recovered_query, $abandoned_order_id ) );
    	                    
    	                    $recovered_order = isset( $recovered_result[0] ) && $recovered_result[0] > 0 ? $recovered_result[0] : 0;
                            $results_sms_sent[$i]->recovered_order_id = $recovered_order;
                            
    	                    
    	                    $results_sms_sent[$i]->display_link = $recovered_order > 0 ? '' : 'Abandoned';
    	                    
    	                    
    	                    $total_sms_sent++;
    	                    if( $results_sms_sent[$i]->date_time_opened != '' ) {
    	                        $total_links_clicked++;
    	                    } 
    	                    $i++;
                        }
                    }
                }
	                
	            
	        }
	        
	        $per_page        = $this->per_page;
	        if ( isset( $_GET['paged'] ) && $_GET['paged'] > 1 ) {
	            $page_number = $_GET['paged'] - 1;
	            $k           = $per_page * $page_number;
	        }else {
	            $k           = 0;
	        }
	         
	        $return_sent_sms_display = array();
	        for ( $j = $k; $j < ( $k + $per_page ); $j++ ) {
	            if ( isset( $results_sms_sent[ $j ] ) ) {
	                $return_sent_sms_display[ $j ] = $results_sms_sent[ $j ];
	            }else {
	                break;
	            }
	        }
	    }
	    
	    $this->total_count = $total_sms_sent;
	    $this->link_click_count = $total_links_clicked;
	    
		return apply_filters( 'wcap_sent_sms_table_data', $return_sent_sms_display );
	}
	
	
	public function column_default( $wcap_sent_sms, $column_name ) {
	    $value = '';
	    
	    $wcap_date_format = get_option( 'date_format' );
	    $wcap_time_format = get_option( 'time_format' );
	     
	    switch ( $column_name ) {

	        case 'sent_time':
	            $value = isset( $wcap_sent_sms->sent_time ) ? date( "$wcap_date_format $wcap_time_format", $wcap_sent_sms->sent_time ) : '';
	            break;
            case 'date_time_opened':
                if( isset( $wcap_sent_sms->date_time_opened ) && strpos( $wcap_sent_sms->date_time_opened, ',' ) >= 0 ) {
                    
                    $link_times = explode( ',', $wcap_sent_sms->date_time_opened );
                    
                    $value = isset( $link_times[0] ) && $link_times[0] != '' ? date( "$wcap_date_format $wcap_time_format", trim( $link_times[0] ) ) : '';
                    $value .= isset( $link_times[1] ) && $link_times[1] != '' ? date( "$wcap_date_format $wcap_time_format", trim( $link_times[1] ) ) : '';
                } else {
                    $value = ( isset( $wcap_sent_sms->date_time_opened ) && $wcap_sent_sms->date_time_opened != '' ) ? date( "$wcap_date_format $wcap_time_format", $wcap_sent_sms->date_time_opened ) : '';
                }
                break;
            case 'link_clicked':
                if( isset( $wcap_sent_sms->link_clicked ) && strpos( $wcap_sent_sms->link_clicked, ',' ) >= 0 ) {
                    $link_names = explode( ',', $wcap_sent_sms->link_clicked );
                    
                    $value = isset( $link_names[0] ) ? $link_names[0] : '';
                    $value .= isset( $link_names[1] ) ? $link_names[1] : '';
                }
                break;
	        default:
				$value = isset( $wcap_sent_sms->$column_name ) ? $wcap_sent_sms->$column_name : '';
				break;
	    }

		return apply_filters( 'wcap_sent_sms_column_default', $value, $wcap_sent_sms, $column_name );
	} 
} 
?>