<?php



if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
global $woocommerce;
$help_tip_text = version_compare( $woocommerce->version, '3.0.0', '>=' ) ? 'help_tip_filter_3.0' : 'help_tip_filter';


$selected_all = 'all' === $match ? 'selected' : '';
$selected_any = 'any' === $match ? 'selected' : '';
$rules_setup  = is_array( $rules ) && count( $rules ) > 0 ? $rules : array();

ob_start();
wc_get_template(
	'html-rules-add-row.php',
	'',
	'xcart/',
	WCAP_PLUGIN_PATH . '/includes/main/rules/'
);
$row = ob_get_clean();
$row = apply_filters( 'wcap_rules_engine_add_row_content', $row );
?>
<table class='form-table'>
	<tr>
		<th>
			<label for='wcap_match_rules'>
				<?php esc_html_e( 'Match Rules:', 'xcart-tr' ); ?>
			</label>
		</th>
		<td>
			<select class='' id='wcap_match_rules' name='wcap_match_rules'>
				<option value='all' <?php echo esc_attr( $selected_all ); ?>><?php esc_html_e( 'Match all rules', 'xcart-tr' ); ?></option>
				<option value='any' <?php echo esc_attr( $selected_any ); ?>><?php esc_html_e( 'Match any rule(s)', 'xcart-tr' ); ?></option>
			</select>
			<img id = <?php echo esc_html( $help_tip_text ); ?> class="help_tip" width="16" height="16" data-tip='<?php esc_html_e( 'Email template will be sent depending on whether all the rule matches are met or any rule matches.', 'xcart-tr' ); ?>' src="<?php echo esc_url( plugins_url() ); ?>/woocommerce/assets/images/help.png" /></p>
		</td>
	</tr>
	<th>
		<label for='wcap_rules_1'>
			<?php esc_html_e( 'Rules:', 'xcart-tr' ); ?>
		</label>
	</th>
	<td>
		<table class='wcap-rule-list form-table' id='wcap-rule-list' data-row='<?php echo esc_attr( $row ); ?>'>
			<?php
			$rule_head_style = ( count( $rules_setup ) > 0 ) ? 'style="display:table-header-group;"' : 'style=display:none;';
			?>
			<thead id='wcap-rule-list-header' <?php echo esc_attr( $rule_head_style ); ?>>
				<tr>
					<th><?php echo esc_html__( 'Rule Type', 'xcart-tr' ); ?></th>
					<th><?php echo esc_html__( 'Conditions', 'xcart-tr' ); ?></th>
					<th><?php echo esc_html__( 'Values', 'xcart-tr' ); ?></th>
					<th><?php echo esc_html__( 'Actions', 'xcart-tr' ); ?></th>
				</tr>
			</thead>
			<tbody id='wcap-rule-list-body'>
			<?php
			if ( count( $rules_setup ) > 0 ) {
				$count = count( $rules_setup );
				$i     = 1;
				foreach ( $rules_setup as $rule_data ) {
					$last_row    = $i === $count ? true : false;
					$rule_emails = isset( $rule_data->emails ) ? $rule_data->emails : '';
					$edit_row    = apply_filters(
						'wcap_rules_engine_edit_row_data',
						array(
							'rule_type'      => $rule_data->rule_type,
							'rule_condition' => $rule_data->rule_condition,
							'rule_value'     => $rule_data->rule_value,
							'rule_emails'    => $rule_emails,
							'last_row'       => $last_row,
							'row_id'         => $i,
						)
					);
					?>
					<tr id='<?php echo esc_attr( $i ); ?>'>
						<?php
						wc_get_template(
							'html-rules-edit-row.php',
							$edit_row,
							'xcart/',
							WCAP_PLUGIN_PATH . '/includes/main/rules/'
						);
						?>
					</tr>
					<?php
					$i++;
				}
			}
			?>
			</tbody>
			<tfoot>
				<tr class="wcap_rule_list_footer_tr">
					<td id="wcap_rule_list_footer" colspan="4">
					<?php
					if ( count( $rules_setup ) === 0 ) {
						?>
						<a
							href="javascript:void(0)"
							id="add_new"
							class="button add-new-row"
							onclick="wcap_add_new_rule_row( this.id )">
							<?php esc_html_e( 'Add new', 'xcart-tr' ); ?>
						</a>
						<?php
					}
					?>
					</td>
				</tr>
			</tfoot>
		</table>
	</td>
</table>
