<?php

if (!defined('ABSPATH')) {
    exit; 
}

if ( !class_exists('Wcap_Update_Check' ) ) {
    
    class Wcap_Update_Check {

        
        public static function wcap_update_db_check() {

            global $wpdb, $woocommerce_ac_plugin_version;
            $woocommerce_ac_plugin_version = get_option( 'woocommerce_ac_db_version' );

            if ( $woocommerce_ac_plugin_version != Wcap_Common::wcap_get_version() ) {

                
                if ( is_multisite() ) {
                    
                    
                    if( 'yes' != get_blog_option( 1, 'wcap_update_multisite' ) ) {
                        
                        Wcap_Activate_Plugin::wcap_activate();
                        update_blog_option( 1, 'wcap_update_multisite', 'yes' );
                    }
                    $blog_list = get_sites();
                    foreach( $blog_list as $blog_list_key => $blog_list_value ) {
                        if( $blog_list_value->blog_id > 1 ){ 
                            $blog_id = $blog_list_value->blog_id;
                            self::wcap_process_db_update( $blog_id );
                        } else { 
                            self::wcap_process_db_update();
                        }
                    }
                } else { 
                    self::wcap_process_db_update();
                }
            }
        }

        static function wcap_process_db_update( $blog_id = 0 ) {
                
            global $woocommerce, $wpdb;

            $db_prefix = ( $blog_id === 0 ) ? $wpdb->prefix : $wpdb->prefix . $blog_id . "_";

            if( $blog_id === 0 ) {
                //get the option, if it is not set to individual then convert to individual records and delete the base record
                $ac_settings = get_option( 'ac_settings_status' );
                if ( $ac_settings != 'INDIVIDUAL' ) {

                    //fetch the existing settings and save them as inidividual to be used for the settings API
                    $woocommerce_ac_settings = json_decode( get_option( 'woocommerce_ac_settings' ) );
                    add_option( 'ac_enable_cart_emails',              $woocommerce_ac_settings[0]->enable_cart_notification );
                    add_option( 'ac_cart_abandoned_time',             $woocommerce_ac_settings[0]->cart_time );
                    add_option( 'ac_delete_abandoned_order_days',     $woocommerce_ac_settings[0]->delete_order_days );
                    add_option( 'ac_email_admin_on_recovery',         $woocommerce_ac_settings[0]->email_admin );
                    add_option( 'ac_track_coupons',                   $woocommerce_ac_settings[0]->track_coupons );
                    add_option( 'ac_disable_guest_cart_email',        $woocommerce_ac_settings[0]->disable_guest_cart );
                    add_option( 'ac_disable_logged_in_cart_email',    $woocommerce_ac_settings[0]->disable_logged_in_cart );
                    add_option( 'ac_track_guest_cart_from_cart_page', $woocommerce_ac_settings[0]->disable_guest_cart_from_cart_page );
                    update_option( 'ac_settings_status', 'INDIVIDUAL' );
                    //Delete the main settings record
                    delete_option( 'woocommerce_ac_settings' );
                }
                update_option( 'woocommerce_ac_db_version', '8.9.0' );
            } else {
                //get the option, if it is not set to individual then convert to individual records and delete the base record
                $ac_settings = get_blog_option( $blog_id, 'ac_settings_status' );
                if ( $ac_settings != 'INDIVIDUAL' ) {

                    //fetch the existing settings and save them as inidividual to be used for the settings API
                    $woocommerce_ac_settings = json_decode( get_blog_option( $blog_id, 'woocommerce_ac_settings' ) );
                    if( ! isset( $woocommerce_ac_settings[0] ) && is_multisite() ) {
                        $woocommerce_ac_settings = json_decode( get_blog_option( 1, 'woocommerce_ac_settings' ) );
                    }
                    add_blog_option( $blog_id, 'ac_enable_cart_emails',              $woocommerce_ac_settings[0]->enable_cart_notification );
                    add_blog_option( $blog_id, 'ac_cart_abandoned_time',             $woocommerce_ac_settings[0]->cart_time );
                    add_blog_option( $blog_id, 'ac_delete_abandoned_order_days',     $woocommerce_ac_settings[0]->delete_order_days );
                    add_blog_option( $blog_id, 'ac_email_admin_on_recovery',         $woocommerce_ac_settings[0]->email_admin );
                    add_blog_option( $blog_id, 'ac_track_coupons',                   $woocommerce_ac_settings[0]->track_coupons );
                    add_blog_option( $blog_id, 'ac_disable_guest_cart_email',        $woocommerce_ac_settings[0]->disable_guest_cart );
                    add_blog_option( $blog_id, 'ac_disable_logged_in_cart_email',    $woocommerce_ac_settings[0]->disable_logged_in_cart );
                    add_blog_option( $blog_id, 'ac_track_guest_cart_from_cart_page', $woocommerce_ac_settings[0]->disable_guest_cart_from_cart_page );
                    update_blog_option( $blog_id, 'ac_settings_status', 'INDIVIDUAL' );
                    //Delete the main settings record
                    delete_blog_option( $blog_id, 'woocommerce_ac_settings' );
                }
                update_blog_option( $blog_id, 'woocommerce_ac_db_version', '8.9.0' );
            }

            $check_table_query = "SHOW COLUMNS FROM `" . $db_prefix . "xcart_link_clicked_email` LIKE 'link_clicked'";
                $results = $wpdb->get_results( $check_table_query );
            if ( isset( $results, $results[0]->Type ) && $results[0]->Type == 'varchar(60)' ) {
                $alter_table_query = "ALTER TABLE `". $db_prefix . "xcart_link_clicked_email` MODIFY COLUMN link_clicked varchar (500)";
                $wpdb->get_results( $alter_table_query );
            }

            
            if ( $wpdb->get_var( "SHOW COLUMNS FROM `". $db_prefix ."xcart_sent` LIKE 'wcap_sent_trash';" ) ) {
                $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_sent DROP COLUMN `wcap_sent_trash`;" );
            }
                
            
            $check_table_query = "SHOW COLUMNS FROM " . $db_prefix . "xcart_ac_history LIKE 'cart_ignored'";
            $results = $wpdb->get_results( $check_table_query );
            if ( isset( $results, $results[0]->Type ) && ( $results[0]->Type == "enum('0','1')" OR $results[0]->Type == "enum('0','1','2')" ) ) {
                $alter_table_query = "ALTER TABLE " . $db_prefix . "xcart_ac_history MODIFY COLUMN cart_ignored enum('0','1','2','3')";
                $wpdb->query( $alter_table_query );
            }
                
            
            $wcap_collate = '';
            if ( $wpdb->has_cap( 'collation' ) ) {
                $wcap_collate = $wpdb->get_charset_collate();
            }
                
            $sql_parent = "CREATE TABLE IF NOT EXISTS " . $db_prefix . "xcart_notifications (
                                `id` int(11) NOT NULL AUTO_INCREMENT,
                                `subject` text COLLATE utf8mb4_unicode_ci,
                                `body` mediumtext COLLATE utf8mb4_unicode_ci NOT NULL,
                                `type` text COLLATE utf8mb4_unicode_ci NOT NULL,
                                `is_active` enum('0','1') COLLATE utf8mb4_unicode_ci NOT NULL,
                                `frequency` text NOT NULL,
                                `coupon_code` varchar(50) COLLATE utf8mb4_unicode_ci NOT NULL,
                                `default_template` enum('0','1') COLLATE utf8mb4_unicode_ci NOT NULL,
                                PRIMARY KEY (`id`)
                                ) $wcap_collate AUTO_INCREMENT=1 ";
            require_once( ABSPATH . 'wp-admin/includes/upgrade.php');
            $wpdb->query( $sql_parent );
                 
            $sql_meta = "CREATE TABLE IF NOT EXISTS " . $db_prefix . "xcart_actionscheduler_claims (
                                `meta_id` int(11) NOT NULL AUTO_INCREMENT,
                                `template_id` int(11) NOT NULL,
                                `meta_key` text COLLATE utf8mb4_unicode_ci NOT NULL,
                                `meta_value` text COLLATE utf8mb4_unicode_ci,
                                PRIMARY KEY(`meta_id`)
                                ) $wcap_collate AUTO_INCREMENT=1";
            require_once( ABSPATH . 'wp-admin/includes/upgrade.php');
            $wpdb->query( $sql_meta );

            $sql_tinyurls = "CREATE TABLE IF NOT EXISTS " . $db_prefix . "xcart_shortlink (
                                    `id` int(11) NOT NULL AUTO_INCREMENT,
                                    `cart_id` int(11) NOT NULL,
                                    `template_id` int(11) NOT NULL,
                                    `long_url` VARCHAR(255) COLLATE utf8mb4_unicode_ci NOT NULL,
                                    `short_code` VARCHAR(10) COLLATE utf8mb4_unicode_ci NOT NULL,
                                    `date_created` int(11) NOT NULL,
                                    `counter` int(11) NOT NULL DEFAULT '0',
                                    `notification_data` VARCHAR(255) COLLATE utf8mb4_unicode_ci NOT NULL,
                                    PRIMARY KEY (`id`),
                                    KEY short_code (`short_code`)
                                    ) $wcap_collate AUTO_INCREMENT=1000000";
                                     
            require_once( ABSPATH . 'wp-admin/includes/upgrade.php');
            $wpdb->query( $sql_tinyurls );

            
            $aelia_table = $db_prefix . "xcart_currency";

            $aelia_sql = "CREATE TABLE IF NOT EXISTS $aelia_table (
                        `id` int(11) NOT NULL AUTO_INCREMENT,
                        `abandoned_cart_id` int(11) COLLATE utf8_unicode_ci NOT NULL,
                        `acfac_currency` text COLLATE utf8_unicode_ci NOT NULL,
                        `date_time` TIMESTAMP on update CURRENT_TIMESTAMP COLLATE utf8_unicode_ci NOT NULL DEFAULT CURRENT_TIMESTAMP,
                        PRIMARY KEY (`id`)
                        ) $wcap_collate AUTO_INCREMENT=1 ";           
            require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
            $wpdb->query( $aelia_sql );
                
            $check_query = "SELECT COUNT(id) FROM " . $db_prefix . "xcart_notifications WHERE `default_template` = '1'";
                 
            $get_count = $wpdb->get_var( $check_query );

            $default_fb_body = array( 
                    '{"header":"We saved your cart","subheader":"Purchase now before they are out of stock","header_image":"' . WCAP_PLUGIN_URL . '/includes/fb-recovery/assets/css/images/carts_div.png","checkout_text":"Checkout Now!","unsubscribe_text":"Unsubscribe"}',
                    '{"header":"You left some items in your cart","subheader":"We have saved some items in your cart","header_image":"' . WCAP_PLUGIN_URL . '/includes/fb-recovery/assets/css/images/carts_div.png","checkout_text":"Checkout","unsubscribe_text":"Unsubscribe"}'
                );

            if( isset( $get_count ) && $get_count == 0 ) {

                
                $insert_templates = "INSERT INTO " . $db_prefix . "xcart_notifications 
                                (`subject`, `body`, `type`, `is_active`, `frequency`, `coupon_code`, `default_template`) 
                                VALUES
                                ( 
                                    NULL,
                                    'متن پیام خود را با استفاده از راهنما تکمیل کنید.', 
                                    'sms', 
                                    '0', 
                                    '30 minutes',
                                    '', 
                                    '1' 
                                ),
                                ( 
                                    NULL,
                                    'Hey {{user.name}}, we have saved your cart at {{shop.name}}. Complete your purchase using {{checkout.link}} now!', 
                                    'sms', 
                                    '0', 
                                    '1 days', 
                                    '',
                                    '1' 
                                ),
                                ( 
                                    'Hey there, We noticed that you left some great products in your cart at " . get_bloginfo( 'name' ) . ". Do not worry we saved them for you:',
                                    '" . $default_fb_body[0] . "', 
                                    'fb', 
                                    '0', 
                                    '30 minutes', 
                                    '',
                                    '1' 
                                ),
                                ( 
                                    'Hey there, There are some great products in your cart you left behind at " . get_bloginfo( 'name' ) . ". Here is a list of items you left behind:',
                                    '" . $default_fb_body[1] . "', 
                                    'fb', 
                                    '0', 
                                    '6 hours', 
                                    '',
                                    '1' 
                                )";
                $wpdb->query( $insert_templates );
            } else if( isset( $get_count ) && $get_count == 2 ) {

                
                
                $insert_fb = "INSERT INTO " . $db_prefix . "xcart_notifications 
                                (`subject`, `body`, `type`, `is_active`, `frequency`, `coupon_code`, `default_template`) 
                                VALUES
                                ( 
                                    'Hey there, We noticed that you left some great products in your cart at " . get_bloginfo( 'name' ) . ". Do not worry we saved them for you:',
                                    '" . $default_fb_body[0] . "', 
                                    'fb', 
                                    '0', 
                                    '30 minutes', 
                                    '',
                                    '1' 
                                ),
                                ( 
                                    'Hey there, There are some great products in your cart you left behind at " . get_bloginfo( 'name' ) . ". Here is a list of items you left behind:',
                                    '" . $default_fb_body[1] . "', 
                                    'fb', 
                                    '0', 
                                    '6 hours', 
                                    '',
                                    '1' 
                                )";
                $wpdb->query( $insert_fb );
            }
                
                
            if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `". $db_prefix."xcart_shortlink` LIKE 'notification_data';" ) ) {
                $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_shortlink ADD `notification_data` VARCHAR(255) COLLATE utf8mb4_unicode_ci NOT NULL;" );
            }

            
            $get_auto = $wpdb->get_results( "SHOW TABLE STATUS FROM `" . DB_NAME . "` WHERE `name` LIKE '" . $db_prefix . "xcart_shortlink'" );
            if( isset( $get_auto[0]->Auto_increment ) && $get_auto[0]->Auto_increment < 1000000 ) {
                $wpdb->query( "ALTER TABLE  ". $db_prefix . "xcart_shortlink AUTO_INCREMENT = 1000000" );
            }

            
            $get_index_cart = "SHOW INDEX FROM " . $db_prefix . "xcart_ac_history WHERE Key_name = 'id'";
            $check_index_cart = $wpdb->get_results( $get_index_cart );
            if( is_array( $check_index_cart ) && count( $check_index_cart ) == 0 ) {
                $add_index_cart = "CREATE UNIQUE INDEX id ON " . $db_prefix . "xcart_ac_history (id)";
                $wpdb->query( $add_index_cart );
            }

            $get_index_guest = "SHOW INDEX FROM " . $db_prefix . "xcart_guest_ac_history WHERE Key_name = 'id'";
            $check_index_guest = $wpdb->get_results( $get_index_guest );
            if( is_array( $check_index_guest ) && count( $check_index_guest ) == 0 ) {
                $add_index_guest = "CREATE UNIQUE INDEX id on " . $db_prefix . "xcart_guest_ac_history (id)";
                $wpdb->query( $add_index_guest );
            }

            $get_index_sent = "SHOW INDEX FROM " . $db_prefix . "xcart_sent WHERE Key_name = 'order_id'";
            $check_index_sent = $wpdb->get_results( $get_index_sent );
            if( is_array( $check_index_sent ) && count( $check_index_sent ) == 0 ) {
                $add_index_sent = "CREATE INDEX order_id on " . $db_prefix . "xcart_sent (abandoned_order_id)";
                $wpdb->query( $add_index_sent );
            }
                
            if( $blog_id === 0 ) {
                $cleanup_data               = get_option( 'ac_pro_user_cleanup', '' );
                $move_templates_data        = get_option( 'wcap_move_templates_data' );
                $wcap_get_admin_option      = get_option( 'ac_email_admin_on_abandoned' );
                $update_sent_history        = get_option( 'wcap_cleanup_sent_history' );
                $update_coupon_code_meta    = get_option( 'wcap_update_coupon_code_meta' );
                
                if ( !get_option( 'ac_cart_abandoned_time_guest' ) ) {
                    $cart_abandoned_time = get_option( 'ac_cart_abandoned_time' );
                    update_option( 'ac_cart_abandoned_time_guest', $cart_abandoned_time );
                }

                $wcap_check_option_available        = "SELECT `option_name` FROM {$db_prefix}options WHERE `option_name` LIKE 'wcap_use_auto_cron'";
                $result_wcap_check_option_available = $wpdb->get_results ($wcap_check_option_available);

                if ( count( $result_wcap_check_option_available ) == 0  ) {
                    $wcap_auto_cron = 'on';
                    update_option( 'wcap_use_auto_cron', $wcap_auto_cron );
                }

                if ( !get_option( 'wcap_cron_time_duration' ) ) {
                    $wcap_cron_duration_time_minutes = 15;
                    update_option( 'wcap_cron_time_duration', $wcap_cron_duration_time_minutes );
                }

                if ( !get_option( 'wcap_new_default_templates' ) ) {
                    $default_template = new Wcap_Default_Settings();
                    $default_template->wcap_create_default_templates( $db_prefix, $blog_id );
                }

            } else {
                $cleanup_data               = get_blog_option( $blog_id, 'ac_pro_user_cleanup' );
                $move_templates_data        = get_blog_option( $blog_id, 'wcap_move_templates_data' );
                $wcap_get_admin_option      = get_blog_option( $blog_id, 'ac_email_admin_on_abandoned' );
                $update_sent_history        = get_blog_option( $blog_id, 'wcap_cleanup_sent_history' );
                $update_coupon_code_meta    = get_blog_option( $blog_id, 'wcap_update_coupon_code_meta' );

                if ( !get_blog_option( $blog_id, 'ac_cart_abandoned_time_guest' ) ) {
                    $cart_abandoned_time = get_blog_option( $blog_id, 'ac_cart_abandoned_time' );
                    update_blog_option( $blog_id, 'ac_cart_abandoned_time_guest', $cart_abandoned_time );
                }

                $wcap_check_option_available        = "SELECT `option_name` FROM {$db_prefix}options WHERE `option_name` LIKE 'wcap_use_auto_cron'";
                $result_wcap_check_option_available = $wpdb->get_results ($wcap_check_option_available);

                if ( count( $result_wcap_check_option_available ) == 0  ) {
                    $wcap_auto_cron = 'on';
                    update_blog_option( $blog_id, 'wcap_use_auto_cron', $wcap_auto_cron );
                }

                if ( !get_blog_option( $blog_id, 'wcap_cron_time_duration' ) ) {
                    $wcap_cron_duration_time_minutes = 15;
                    update_blog_option( $blog_id, 'wcap_cron_time_duration', $wcap_cron_duration_time_minutes );
                }

                if ( !get_blog_option( $blog_id, 'wcap_new_default_templates' ) ) {
                    $default_template = new Wcap_Default_Settings();
                    $default_template->wcap_create_default_templates( $db_prefix, $blog_id );
                }
            }
            
            if ( 'yes' !== $cleanup_data ) {
                $query_cleanup = "UPDATE `" . $db_prefix . "xcart_guest_ac_history` SET 
                        billing_first_name = IF (billing_first_name LIKE '%<%', '', billing_first_name),
                        billing_last_name = IF (billing_last_name LIKE '%<%', '', billing_last_name),
                        billing_company_name = IF (billing_company_name LIKE '%<%', '', billing_company_name),
                        billing_address_1 = IF (billing_address_1 LIKE '%<%', '', billing_address_1),
                        billing_address_2 = IF (billing_address_2 LIKE '%<%', '', billing_address_2),
                        billing_city = IF (billing_city LIKE '%<%', '', billing_city),
                        billing_county = IF (billing_county LIKE '%<%', '', billing_county),
                        billing_zipcode = IF (billing_zipcode LIKE '%<%', '', billing_zipcode),
                        email_id = IF (email_id LIKE '%<%', '', email_id),
                        phone = IF (phone LIKE '%<%', '', phone),
                        ship_to_billing = IF (ship_to_billing LIKE '%<%', '', ship_to_billing),
                        order_notes = IF (order_notes LIKE '%<%', '', order_notes),
                        shipping_first_name = IF (shipping_first_name LIKE '%<%', '', shipping_first_name),
                        shipping_last_name = IF (shipping_last_name LIKE '%<%', '', shipping_last_name),
                        shipping_company_name = IF (shipping_company_name LIKE '%<%', '', shipping_company_name),
                        shipping_address_1 = IF (shipping_address_1 LIKE '%<%', '', shipping_address_1),
                        shipping_address_2 = IF (shipping_address_2 LIKE '%<%', '', shipping_address_2),
                        shipping_city = IF (shipping_city LIKE '%<%', '', shipping_city),
                        shipping_county = IF (shipping_county LIKE '%<%', '', shipping_county)";

                $wpdb->query( $query_cleanup );

                $email = 'woouser401a@mailinator.com';
                $exists = email_exists( $email );
                if ( $exists ) {
                    wp_delete_user( esc_html( $exists ) );
                }

                if( $blog_id === 0 ) {
                    update_option( 'ac_pro_user_cleanup', 'yes' );
                } else {
                    update_blog_option( $blog_id, 'ac_pro_user_cleanup', 'yes' );
                }
            }

            
            if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `". $db_prefix."xcart_et` LIKE 'cart_rules';" ) ) {
                $wpdb->query( "ALTER TABLE ". $db_prefix."xcart_et ADD `cart_rules` varchar(50) COLLATE   utf8_unicode_ci NOT NULL AFTER `wc_template_filter`;" );
            }

            if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `". $db_prefix."xcart_et` LIKE 'product_ids';" ) ) {
                $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_et ADD `product_ids` varchar(100) COLLATE     utf8_unicode_ci NOT NULL AFTER `cart_rules`;" );
            }

            
            if( 'yes' != $move_templates_data ) {
                $columns_added = false; 
                if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `". $db_prefix ."xcart_et` LIKE 'send_emails_to'" ) ) {
                    $wpdb->query( "ALTER TABLE " . $db_prefix . "xcart_et ADD `send_emails_to` VARCHAR(300) NOT NULL AFTER `product_ids`" );
                    $columns_added = true;
                }

                if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `".$db_prefix."xcart_et` LIKE 'activated_time'" ) ) {
                    $wpdb->query( "ALTER TABLE " . $db_prefix . "xcart_et ADD `activated_time` int(11) NOT NULL AFTER `send_emails_to`" );
                    $columns_added = true;
                }

                //
                $email_templates = $wpdb->get_col( "SELECT id FROM " . $db_prefix . "xcart_et" );
                if( is_array( $email_templates ) && $columns_added ) {
                    
                    foreach( $email_templates as $id ) {
                        $activated_time = get_post_meta( $id, 'wcap_template_time', true );
                        $email_action = get_post_meta( $id, 'wcap_email_action', true );
                        $other_action = get_post_meta( $id, 'wcap_other_emails', true );

                        $send_emails_data = json_encode( array(  'action' => $email_action,
                                                    'others' => trim( implode( ',', explode( PHP_EOL, $other_action ) ) ) ) );
                        $update_array = [  'activated_time' => $activated_time,
                                        'send_emails_to' => $send_emails_data ];

                        $wpdb->update( $db_prefix . "xcart_et", $update_array, array( 'id' => $id ) );

                    }

                    
                    $wpdb->query( "DELETE FROM `" . $db_prefix . "postmeta` WHERE meta_key = 'wcap_template_time'" );
                    $wpdb->query( "DELETE FROM `" . $db_prefix . "postmeta` WHERE meta_key = 'wcap_email_action'" );
                    $wpdb->query( "DELETE FROM `" . $db_prefix . "postmeta` WHERE meta_key = 'wcap_other_emails'" ); 
    
                }

                if( $blog_id === 0 ) {
                    update_option( 'wcap_move_templates_data', 'yes' );
                } else {
                    update_blog_option( $blog_id, 'wcap_move_templates_data', 'yes' );
                }
            }
            
            
            if ( '' == $update_sent_history ) {
                $last_365 = date( 'Y-m-d H:i:s', strtotime( '-365 days', current_time( 'timestamp' ) ) );
                $wpdb->query( "UPDATE " . WCAP_EMAIL_SENT_HISTORY_TABLE . " as sent LEFT JOIN " . WCAP_EMAIL_CLICKED_TABLE . " as link ON sent.id = link.email_sent_id SET sent.recovered_order = '0' where link.id IS NULL AND sent.recovered_order = '1' AND sent.sent_time > '$last_365'" );

                if ( 0 === $blog_id ) {
                    update_option( 'wcap_cleanup_sent_history', 'yes' );
                } else {
                    update_blog_option( $blog_id, 'wcap_cleanup_sent_history', 'yes' );
                }

            }

            
            if ( 'yes' !== $update_coupon_code_meta ) {

                $coupons = $wpdb->get_col( $wpdb->prepare( 'SELECT id from `' . $db_prefix . 'posts` WHERE post_type = %s AND post_status = %s AND post_content = %s', 'shop_coupon', 'publish', "This coupon provides 5% discount on cart price." ) );
                
		    foreach ( $coupons as $key => $coupon_id ) {
                    update_post_meta( $coupon_id, 'wcap_created_by', 'wcap' );
                }

                if ( $blog_id === 0 ) {
                    update_option( 'wcap_update_coupon_code_meta', 'yes' );
                    update_option( 'ac_cart_abandoned_after_x_days_order_placed', 7 );
                } else {
                    update_blog_option( $blog_id, 'wcap_update_coupon_code_meta', 'yes' );
                    update_blog_option( $blog_id, 'ac_cart_abandoned_after_x_days_order_placed', 7 );
                }
            }
            
            
            if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `".$db_prefix."xcart_ac_history` LIKE 'checkout_link'" ) ) {
                $wpdb->query( "ALTER TABLE " . $db_prefix . "xcart_ac_history ADD `checkout_link` varchar(200) NOT NULL AFTER `wcap_trash`" );
            }

			
			if ( ! $wpdb->get_var( "SHOW COLUMNS FROM " . $db_prefix . "xcart_et LIKE 'individual_use'" ) ) { 
				$wpdb->query( "ALTER TABLE `" . $db_prefix . "xcart_et` ADD `individual_use` ENUM('0','1') NOT NULL AFTER `discount_expiry`;" ); 
				
				$get_ids = $wpdb->get_col( "SELECT id FROM `" . $db_prefix . "xcart_et` WHERE generate_unique_coupon_code = '1'" ); 

				if ( is_array( $get_ids ) && count( $get_ids ) > 0 ) {
					foreach ( $get_ids as $template_id ) {
						$wpdb->update(
							$db_prefix . 'xcart_et',
							array( 'individual_use' => '1' ),
							array( 'id' => $template_id )
						);
					}
				}
			}
            
            
            Wcap_Update_Check::wcap_alter_tables_if_required( $db_prefix, $blog_id );
            Wcap_Update_Check::wcap_update_options_if_required( $blog_id );

            if ( ( $wcap_get_admin_option == 'on' || '' == $wcap_get_admin_option ) && false !== $wcap_get_admin_option ) {
                Wcap_Update_Check::wcap_add_customer_for_template( $db_prefix, $blog_id );
            }
        }

        
        public static function wcap_alter_tables_if_required( $db_prefix = '', $blog_id = 0 ) {

            if( $db_prefix === '' ) {
                return;
            }

            if( $blog_id === 0 ) {
                $guest_user_id_altered = get_option ('wcap_guest_user_id_altered');
                $alter_tables_ran = get_option( 'wcap_alter_tables_ran' );
                $alter_guest_columns = get_option( 'wcap_alter_guest_columns' );
            } else {
                $guest_user_id_altered = get_blog_option( $blog_id, 'wcap_guest_user_id_altered');
                $alter_tables_ran = get_blog_option( $blog_id, 'wcap_alter_tables_ran' );
                $alter_guest_columns = get_blog_option( $blog_id, 'wcap_alter_guest_columns' );
            }

            global $wpdb;
            if ( $wpdb->get_var( "SHOW TABLES LIKE '".$db_prefix."xcart_guest_ac_history' " )  && 'yes' != $guest_user_id_altered ) {
                $last_id = $wpdb->get_var( "SELECT max(id) FROM `".$db_prefix."xcart_guest_ac_history`;" );
                if ( NULL != $last_id && $last_id <= 63000000 ) {
                    $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_guest_ac_history AUTO_INCREMENT = 63000000;" );
                    update_option ( 'wcap_guest_user_id_altered' , 'yes' );
                }
            }
            if ( '1' != $alter_tables_ran ) {

                if ( $wpdb->get_var( "SHOW TABLES LIKE '".$db_prefix."xcart_et' " ) ) {
                    
                    if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `".$db_prefix."xcart_et` LIKE 'wc_template_filter';" ) ) {
                        $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_et ADD `wc_template_filter` varchar(500) COLLATE utf8_unicode_ci NOT NULL AFTER `wc_email_header`;" );
                    }
                }
                
                if ( $wpdb->get_var( "SHOW TABLES LIKE '".$db_prefix."xcart_ac_history' " ) ) {
                    if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `".$db_prefix."xcart_ac_history` LIKE 'language';" ) ) {
                        $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_ac_history ADD `language` varchar(50) COLLATE utf8_unicode_ci NOT NULL AFTER `user_type`;" );
                    }
                    
                    if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `".$db_prefix."xcart_ac_history` LIKE 'session_id';" ) ) {
                        $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_ac_history ADD `session_id` varchar(50) COLLATE utf8_unicode_ci NOT NULL AFTER `language`;" );
                    }
                    
                    if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `".$db_prefix."xcart_ac_history` LIKE 'ip_address';" ) ) {
                        $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_ac_history ADD `ip_address` longtext COLLATE utf8_unicode_ci NOT NULL AFTER  `session_id`;" );
                    }
                    
                    if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `".$db_prefix."xcart_ac_history` LIKE 'manual_email';" ) ) {
                        $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_ac_history ADD `manual_email` varchar(50) COLLATE utf8_unicode_ci NOT NULL AFTER `ip_address`;" );
                    }
                    
                    if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `".$db_prefix."xcart_ac_history` LIKE 'wcap_trash';" ) ) {
                        $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_ac_history ADD `wcap_trash` varchar(1) COLLATE utf8_unicode_ci NOT NULL AFTER `manual_email`;" );
                    }
                }

                
                if ( $wpdb->get_var( "SHOW TABLES LIKE '". $db_prefix ."xcart_sent'" ) ) {
                    if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `".$db_prefix."xcart_sent` LIKE 'wcap_sent_trash';" ) ) {
                        $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_sent ADD `wcap_sent_trash` varchar(1) COLLATE utf8_unicode_ci NOT NULL AFTER `recovered_order`;" );
                    }
                }
                
        

                
                if ( $wpdb->get_var( "SHOW TABLES LIKE '".$db_prefix."xcart_et' " ) ) {

                    if ( $wpdb->get_var( "SHOW COLUMNS FROM `".$db_prefix."xcart_et` LIKE 'from_email';" ) ) {
                        $get_email_template_query  = "SELECT `from_email` FROM ".$db_prefix."xcart_et WHERE `is_active` = '1' ORDER BY `id` ASC LIMIT 1";
                        $get_email_template_result = $wpdb->get_results ($get_email_template_query);

                        $wcap_from_email = '';
                        if ( isset( $get_email_template_result ) && count ( $get_email_template_result ) > 0 ) {
                            $wcap_from_email =  $get_email_template_result[0]->from_email;

                            
                            if( $blog_id === 0 ) {
                                update_option ( 'wcap_from_email', $wcap_from_email );
                            } else {
                                update_blog_option( $blog_id, 'wcap_from_email', $wcap_from_email );
                            }   

                            
                            $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_et DROP COLUMN `from_email`;" );
                        }
                    }

                    if ( $wpdb->get_var( "SHOW COLUMNS FROM `".$db_prefix."xcart_et` LIKE 'from_name';" ) ) {
                        $get_email_template_from_name_query  = "SELECT `from_name` FROM ".$db_prefix."xcart_et WHERE `is_active` = '1' ORDER BY `id` ASC LIMIT 1";
                        $get_email_template_from_name_result = $wpdb->get_results ($get_email_template_from_name_query);

                        $wcap_from_name = '';
                        if ( isset( $get_email_template_from_name_result ) && count ( $get_email_template_from_name_result ) > 0 ){
                            $wcap_from_name =  $get_email_template_from_name_result[0]->from_name;

                            
                            if( $blog_id === 0 ) {
                                update_option( 'wcap_from_name', $wcap_from_name );
                            } else {
                                update_blog_option( $blog_id, 'wcap_from_name', $wcap_from_name );
                            }

                            
                            $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_et DROP COLUMN `from_name`;" );
                        }
                    }

                    if ( $wpdb->get_var( "SHOW COLUMNS FROM `".$db_prefix."xcart_et` LIKE 'reply_email';" ) ) {
                        $get_email_template_reply_email_query  = "SELECT `reply_email` FROM ".$db_prefix."xcart_et WHERE `is_active` = '1' ORDER BY `id` ASC LIMIT 1";
                        $get_email_template_reply_email_result = $wpdb->get_results ($get_email_template_reply_email_query);

                        $wcap_reply_email = '';
                        if ( isset( $get_email_template_reply_email_result ) && count ( $get_email_template_reply_email_result ) > 0 ){
                            $wcap_reply_email =  $get_email_template_reply_email_result[0]->reply_email;

                            
                            if( $blog_id === 0 ) {
                                update_option( 'wcap_reply_email', $wcap_reply_email );
                            } else {
                                update_option( $blog_id, 'wcap_reply_email', $wcap_reply_email );
                            }

                            
                            $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_et DROP COLUMN `reply_email`;" );
                        }
                    }
                }

                if( $blog_id === 0 ) {
                    update_option( 'wcap_alter_tables_ran', '1', 'no' );
                } else {
                    update_blog_option( $blog_id, 'wcap_alter_tables_ran', '1' );
                }
            }

            if ( '1' != $alter_guest_columns ) {
                $wpdb->query( "
                    ALTER TABLE " . $db_prefix . "xcart_guest_ac_history 
                    ADD billing_country TEXT AFTER billing_last_name" );
                if( $blog_id === 0 ) {
                    update_option( 'wcap_alter_guest_columns', '1', 'no' );
                } else {
                    update_blog_option( $blog_id, 'wcap_alter_guest_columns', '1' );
                }
            }

            
            if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `". $db_prefix."xcart_et` LIKE 'discount_type';" ) ) {                
                $wpdb->query( "ALTER TABLE ".$db_prefix."xcart_et ADD `discount_type` VARCHAR(50) DEFAULT 'percent' AFTER `discount`, ADD `discount_shipping` VARCHAR(50) DEFAULT 'no' AFTER `discount_type`, ADD `discount_expiry` VARCHAR(50) DEFAULT '7-days' AFTER `discount_shipping`;" );
            }

			
			if ( 'yes' !== get_option( 'wcap_rules_engine_edit_email_templates_table', '' ) ) {

				
				if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `". $db_prefix."xcart_et` LIKE 'match_rules';" ) ) {                
					$wpdb->query( "ALTER TABLE ".$db_prefix."xcart_et ADD `match_rules` VARCHAR(50) DEFAULT 'all' AFTER `send_emails_to`, ADD `rules` VARCHAR(500) AFTER `match_rules`;" );
				}
				
				$emails = $wpdb->get_results(
					'SELECT id, wc_template_filter, cart_rules, product_ids, send_emails_to FROM ' . $db_prefix . 'xcart_et'
				);

				$match_rules = 'all';
				
				foreach ( $emails as $data ) {
                    $send_to = false;
					$rules = array();
					if ( '' !== $data->wc_template_filter ) {
						switch( $data->wc_template_filter ) {
							case 'all':
							default:
								$rule_type = 'send_to';
								$rule_condition = 'includes';
								$rule_value = array( 'all' );
                                $send_to = true;
							break;
							case 'Carts abandoned with one product':
								$rule_type = 'cart_items_count';
								$rule_condition = 'equal_to';
								$rule_value = 1;
							break;
							case 'Carts abandoned with more than one product':
								$rule_type = 'cart_items_count';
								$rule_condition = 'greater_than_equal_to';
								$rule_value = 1;
							break;
							case 'Registered Users':
								$rule_type = 'send_to';
								$rule_condition = 'includes';
								$rule_value = array( 'registered_users' );
                                $send_to = true;
							break;
							case 'Guest Users':
								$rule_type = 'send_to';
								$rule_condition = 'includes';
                                $rule_value = array( 'guest_users' );
                                $send_to = true;
							break;
						}
						$rules[] = array(
							'rule_type' => $rule_type,
							'rule_condition' => $rule_condition,
							'rule_value' => $rule_value,
						);
					}
					
					if ( '' !== $data->cart_rules && '' !== $data->product_ids ) {
						$product_list = strpos( $data->product_ids, ',' ) !== false ? explode( ',', $data->product_ids ) : array( $data->product_ids );
						$rules[] = array(
							'rule_type' => 'cart_items',
							'rule_condition' => $data->cart_rules,
							'rule_value' => $product_list,
						);
					}

					if ( '' !== $data->send_emails_to ) {
						$send_emails_to = json_decode( $data->send_emails_to );
						$action = $send_emails_to->action;
						$others = $send_emails_to->others;

                        if ( $send_to ) {
                            foreach ( $rules as $r_key => $rule_data ) {
                                if ( 'send_to' === $rule_data['rule_type'] ) {
                                    $existing_rule = $rule_data['rule_value'];
                                    if ( '' !== $others ) {  
                                        $action = 'email_addresses';
                                        $rule_data['emails'] = $others;
                                    }
                                    array_push( $existing_rule, $action );
                                    $rule_data['rule_value'] = $existing_rule;
                                    $rules[$r_key] = $rule_data;
                                }
                            }
                        } else {	
							if ( '' !== $others ) {
								$rules[] = array(
									'rule_type' => 'send_to',
									'rule_condition' => 'includes',
									'rule_value' => array( 'email_addresses' ),
									'emails' => $others,
								);
							} else {
								$rules[] = array(
									'rule_type' => 'send_to',
									'rule_condition' => 'includes',
									'rule_value' => array( $action ),
								);
							}
						}
					}

					$wpdb->update(
						$db_prefix . 'xcart_et',
						array(
							'match_rules' => $match_rules,
							'rules'       => json_encode( $rules )
						),
						array(
							'id' => $data->id
						)
					);

				}

				
				$wpdb->query( 'ALTER TABLE ' . $db_prefix . 'xcart_et DROP wc_template_filter, DROP cart_rules, DROP product_ids, DROP send_emails_to' );
				update_option( 'wcap_rules_engine_edit_email_templates_table', 'yes' );
            }

            $check_table_query = "SHOW COLUMNS FROM " . $db_prefix . "xcart_ac_history LIKE 'cart_ignored'";
            $results = $wpdb->get_results( $check_table_query );
            if ( isset( $results, $results[0]->Type ) && ( $results[0]->Type == "enum('0','1')" OR $results[0]->Type == "enum('0','1','2')" OR $results[0]->Type == "enum('0','1','2','3')" ) ) {
                $alter_table_query = "ALTER TABLE " . $db_prefix . "xcart_ac_history MODIFY COLUMN cart_ignored enum('0','1','2','3','4')";
                $wpdb->query( $alter_table_query );
            }

        }

        
        public static function wcap_update_options_if_required( $blog_id = 0 ) {

            $wcap_atc_heading = 'ادامه فرآیند سفارش';
            $wcap_atc_heading_color = '#737f97';
            $wcap_atc_sub_text = 'لطفا شماره تماس خود را وارد نمایید.';
            $wcap_atc_sub_text_color = '#bbc9d2';
            $wcap_atc_email_field_placeholder = 'مثال: 09121112222';
            $wcap_atc_button = 'ادامه سفارش';
            $wcap_atc_button_color = '#0085ba';
            $wcap_atc_button_text_color = '#ffffff';
            $wcap_atc_non_mandatory_text = 'رد کردن';
            $wcap_atc_mandatory = 'خاموش';
            $wcap_atc_email_mandatory = 'روشن';
            $wcap_countdown_cart = 'روشن';
            $countdown_timer_msg = 'کد تخفیف <coupon_code> تا تاریخ <hh:mm:ss>. فعال است.';
            
            if( $blog_id === 0 ) {
                if ( '1' != get_option( 'wcap_update_options_ran' ) ) {

                    if ( !get_option( 'ac_security_key' ) ){
                        update_option( 'ac_security_key', "qJB0rGtIn5UB1xG03efyCp" );
                    }

                    if ( !get_option( 'wcap_product_image_height' ) ) {
                        update_option( 'wcap_product_image_height', $wcap_product_image_height_px);
                    }

                    if ( !get_option( 'wcap_product_image_width' ) ) {
                        update_option( 'wcap_product_image_width', $wcap_product_image_width_px );
                    }

                    if ( !get_option( 'wcap_heading_section_text_email' ) ) {
                        add_option( 'wcap_heading_section_text_email', $wcap_atc_heading );
                    }
                    
                    if ( !get_option( 'wcap_popup_heading_color_picker' ) ) {
                        add_option( 'wcap_popup_heading_color_picker', $wcap_atc_heading_color );
                    }

                    if ( !get_option( 'wcap_text_section_text' ) ) {
                        add_option( 'wcap_text_section_text', $wcap_atc_sub_text );
                    }

                    if ( !get_option( 'wcap_popup_text_color_picker' ) ) {
                        add_option( 'wcap_popup_text_color_picker', $wcap_atc_sub_text_color );
                    }

                    if ( !get_option( 'wcap_email_placeholder_section_input_text' ) ) {
                        add_option( 'wcap_email_placeholder_section_input_text', $wcap_atc_email_field_placeholder );
                    }

                    if ( !get_option( 'wcap_button_section_input_text' ) ) {
                        add_option( 'wcap_button_section_input_text', $wcap_atc_button );
                    }

                    if ( !get_option( 'wcap_button_color_picker' ) ) {
                        add_option( 'wcap_button_color_picker', $wcap_atc_button_color );
                    }

                    if ( !get_option( 'wcap_button_text_color_picker' ) ) {
                        add_option( 'wcap_button_text_color_picker', $wcap_atc_button_text_color );
                    }
                    
                    if ( !get_option( 'wcap_non_mandatory_text' ) ) {
                        add_option( 'wcap_non_mandatory_text', $wcap_atc_non_mandatory_text );
                    }
                    
                    if ( !get_option( 'wcap_atc_enable_modal' ) ) {
                        add_option( 'wcap_atc_enable_modal', $wcap_atc_mandatory );
                    }
                    
                    if ( !get_option( 'wcap_atc_mandatory_email' ) ) {
                        add_option( 'wcap_atc_mandatory_email', $wcap_atc_email_mandatory );
                    }

                    update_option( 'wcap_update_options_ran', '1', 'no' );

                }

                if ( !get_option( 'wcap_fb_consent_text' ) ) {
                    add_option( 'wcap_fb_consent_text', 'Allow order status to be sent to Facebook Messenger' );
                }

                if( !get_option( 'wcap_countdown_cart' ) ) {
                    add_option( 'wcap_countdown_cart', $wcap_countdown_cart );
                }

                if( !get_option( 'wcap_countdown_timer_msg' ) ) {
					add_option( 'wcap_countdown_timer_msg', $countdown_timer_msg );
                }
                
                if( false === get_option( 'wcap_atc_coupon_validity_minutes', false ) ) {
                    if( 0 < get_option( 'wcap_atc_popup_coupon_validity', 0 ) ) {
                        $validity_in_minutes = get_option( 'wcap_atc_popup_coupon_validity' ) * 60;
                        update_option( 'wcap_atc_popup_coupon_validity', $validity_in_minutes );
                        update_option( 'wcap_atc_coupon_validity_minutes', true );
                    }
                }
            } else {

                if ( '1' != get_blog_option( $blog_id, 'wcap_update_options_ran' ) ) {

                    if ( !get_blog_option( $blog_id, 'ac_security_key' ) ){
                        update_blog_option( $blog_id, 'ac_security_key', "qJB0rGtIn5UB1xG03efyCp" );
                    }

                    if ( !get_blog_option( $blog_id, 'wcap_product_image_height' ) ) {
                        update_blog_option( $blog_id, 'wcap_product_image_height', $wcap_product_image_height_px);
                    }

                    if ( !get_blog_option( $blog_id, 'wcap_product_image_width' ) ) {
                        update_blog_option( $blog_id, 'wcap_product_image_width', $wcap_product_image_width_px );
                    }

                    if ( !get_blog_option( $blog_id, 'wcap_heading_section_text_email' ) ) {
                        add_blog_option( $blog_id, 'wcap_heading_section_text_email', $wcap_atc_heading );
                    }
                    
                    if ( !get_blog_option( $blog_id, 'wcap_popup_heading_color_picker' ) ) {
                        add_blog_option( $blog_id, 'wcap_popup_heading_color_picker', $wcap_atc_heading_color );
                    }

                    if ( !get_blog_option( $blog_id, 'wcap_text_section_text' ) ) {
                        add_blog_option( $blog_id, 'wcap_text_section_text', $wcap_atc_sub_text );
                    }

                    if ( !get_blog_option( $blog_id, 'wcap_popup_text_color_picker' ) ) {
                        add_blog_option( $blog_id, 'wcap_popup_text_color_picker', $wcap_atc_sub_text_color );
                    }

                    if ( !get_blog_option( $blog_id, 'wcap_email_placeholder_section_input_text' ) ) {
                        add_blog_option( $blog_id, 'wcap_email_placeholder_section_input_text', $wcap_atc_email_field_placeholder );
                    }

                    if ( !get_blog_option( $blog_id, 'wcap_button_section_input_text' ) ) {
                        add_blog_option( $blog_id, 'wcap_button_section_input_text', $wcap_atc_button );
                    }

                    if ( !get_blog_option( $blog_id, 'wcap_button_color_picker' ) ) {
                        add_blog_option( $blog_id, 'wcap_button_color_picker', $wcap_atc_button_color );
                    }

                    if ( !get_blog_option( $blog_id, 'wcap_button_text_color_picker' ) ) {
                        add_blog_option( $blog_id, 'wcap_button_text_color_picker', $wcap_atc_button_text_color );
                    }
                    
                    if ( !get_blog_option( $blog_id, 'wcap_non_mandatory_text' ) ) {
                        add_blog_option( $blog_id, 'wcap_non_mandatory_text', $wcap_atc_non_mandatory_text );
                    }
                    
                    if ( !get_blog_option( $blog_id, 'wcap_atc_enable_modal' ) ) {
                        add_blog_option( $blog_id, 'wcap_atc_enable_modal', $wcap_atc_mandatory );
                    }
                    
                    if ( !get_blog_option( $blog_id, 'wcap_atc_mandatory_email' ) ) {
                        add_blog_option( $blog_id, 'wcap_atc_mandatory_email', $wcap_atc_email_mandatory );
                    }

                    update_blog_option( $blog_id, 'wcap_update_options_ran', '1' );

                }

                if ( !get_blog_option( $blog_id, 'wcap_fb_consent_text' ) ) {
                    add_blog_option( $blog_id, 'wcap_fb_consent_text', 'Allow order status to be sent to Facebook Messenger' );
                }

                if( !get_blog_option( $blog_id, 'wcap_countdown_cart' ) ) {
                    add_blog_option( $blog_id, 'wcap_countdown_cart', $wcap_countdown_cart );
                }

                if( !get_blog_option( $blog_id, 'wcap_countdown_timer_msg' ) ) {
					add_blog_option( $blog_id, 'wcap_countdown_timer_msg', $countdown_timer_msg );
                }
                
                if( false === get_blog_option( $blog_id, 'wcap_atc_coupon_validity_minutes', false ) ) {
                    if( 0 < get_blog_option( $blog_id, 'wcap_atc_popup_coupon_validity', 0 ) ) {
                        $validity_in_minutes = get_blog_option( $blog_id, 'wcap_atc_popup_coupon_validity' ) * 60;
                        update_blog_option( $blog_id, 'wcap_atc_popup_coupon_validity', $validity_in_minutes );
                        update_blog_option( $blog_id, 'wcap_atc_coupon_validity_minutes', true );
                    }
                }
            }
            
        }
        
        public static function wcap_add_customer_for_template( $db_prefix, $blog_id ) {
            global $wpdb;

            $wcap_get_all_template   = "SELECT id FROM ". $db_prefix . "xcart_et";
            $wcap_result_of_template = $wpdb->get_results ( $wcap_get_all_template );

            if( $blog_id === 0 ) {
                $wcap_admin_setting = get_option ('ac_email_admin_on_abandoned');
            } else {
                $wcap_admin_setting = get_blog_option( $blog_id, 'ac_email_admin_on_abandoned');
            }

            if ( isset( $wcap_admin_setting ) && 'on' == $wcap_admin_setting ) {
                $wcap_customers_key = 'wcap_email_customer_admin';
            }else{
                $wcap_customers_key = 'wcap_email_customer';
            }
            if ( count( $wcap_result_of_template ) > 0 ) {

                foreach ($wcap_result_of_template as $wcap_result_of_template_key => $wcap_result_of_template_value ) {
                    add_post_meta( $wcap_result_of_template_value->id , 'wcap_email_action', $wcap_customers_key );
                }

                if( $blog_id === 0 ) {
                    delete_option ( 'ac_email_admin_on_abandoned' );
                } else {
                    delete_blog_option ( $blog_id, 'ac_email_admin_on_abandoned' );
                }
            
            }
        }

		
        public static function wcap_update_postmeta_coupons() {

			global $wpdb;
			
			$cart_ids = $wpdb->get_results(
				"SELECT id from " . WCAP_ABANDONED_CART_HISTORY_TABLE . " AS cart_history INNER JOIN " . $wpdb->prefix . "postmeta as meta ON cart_history.id = meta.post_id where cart_history.cart_ignored = '0' and meta.meta_key = '_woocommerce_ac_coupon'"
			);
    
			
			if ( is_array( $cart_ids ) && count( $cart_ids ) > 100 ) {
				$chunks = array_chunk( $cart_ids, 100 );
			} else {
				$chunks[0] = $cart_ids;
			}
            
            
			foreach( $chunks as $coupon_meta ) {
				foreach( $coupon_meta as $coupon_details ) {
					$post_id = $coupon_details->id;
					$coupon_data = get_post_meta( $post_id, '_woocommerce_ac_coupon' );
                    update_post_meta( $post_id, '_woocommerce_ac_coupon', $coupon_data );
				}
			}
                    
        }
    }
}
